# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qm/pb/frontend.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from qm.pb import inc_qua_pb2 as qm_dot_pb_dot_inc__qua__pb2
from qm.pb import inc_qua_config_pb2 as qm_dot_pb_dot_inc__qua__config__pb2
from qm.pb import inc_qm_api_pb2 as qm_dot_pb_dot_inc__qm__api__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from qm.pb import compiler_pb2 as qm_dot_pb_dot_compiler__pb2
from qm.pb import job_results_pb2 as qm_dot_pb_dot_job__results__pb2
from qm.pb import qm_manager_pb2 as qm_dot_pb_dot_qm__manager__pb2
from qm.pb import general_messages_pb2 as qm_dot_pb_dot_general__messages__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='qm/pb/frontend.proto',
  package='qm.grpc.frontend',
  syntax='proto3',
  serialized_options=b'\n\020qm.grpc.frontendB\rFrontendProtoP\001\242\002\003HLW',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14qm/pb/frontend.proto\x12\x10qm.grpc.frontend\x1a\x13qm/pb/inc_qua.proto\x1a\x1aqm/pb/inc_qua_config.proto\x1a\x16qm/pb/inc_qm_api.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x14qm/pb/compiler.proto\x1a\x17qm/pb/job_results.proto\x1a\x16qm/pb/qm_manager.proto\x1a\x1cqm/pb/general_messages.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"k\n\rQueuePosition\x12%\n\x03\x65nd\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\'\n\x05start\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x42\n\n\x08position\"\x98\x01\n\x11\x41\x64\x64ToQueueRequest\x12\x18\n\x10quantumMachineId\x18\x01 \x01(\t\x12\x31\n\x10highLevelProgram\x18\x02 \x01(\x0b\x32\x17.qm.grpc.qua.QuaProgram\x12\x36\n\rqueuePosition\x18\x03 \x01(\x0b\x32\x1f.qm.grpc.frontend.QueuePosition\"d\n\x12\x41\x64\x64ToQueueResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\r\n\x05jobId\x18\x02 \x01(\t\x12\x33\n\x08messages\x18\x03 \x03(\x0b\x32!.qm.grpc.compiler.CompilerMessage\"#\n\x10WaveformOverride\x12\x0f\n\x07samples\x18\x01 \x03(\x01\"\xb2\x01\n\x12\x45xecutionOverrides\x12\x46\n\twaveforms\x18\x01 \x03(\x0b\x32\x33.qm.grpc.frontend.ExecutionOverrides.WaveformsEntry\x1aT\n\x0eWaveformsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".qm.grpc.frontend.WaveformOverride:\x02\x38\x01\"\xc2\x01\n\x19\x41\x64\x64\x43ompiledToQueueRequest\x12\x18\n\x10quantumMachineId\x18\x01 \x01(\t\x12\x11\n\tprogramId\x18\x02 \x01(\t\x12\x36\n\rqueuePosition\x18\x03 \x01(\x0b\x32\x1f.qm.grpc.frontend.QueuePosition\x12@\n\x12\x65xecutionOverrides\x18\x04 \x01(\x0b\x32$.qm.grpc.frontend.ExecutionOverrides\"o\n\x1a\x41\x64\x64\x43ompiledToQueueResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\r\n\x05jobId\x18\x02 \x01(\t\x12\x36\n\x06\x65rrors\x18\x03 \x03(\x0b\x32&.qm.grpc.general_messages.ErrorMessage\"]\n\x0e\x43ompileRequest\x12\x18\n\x10quantumMachineId\x18\x01 \x01(\t\x12\x31\n\x10highLevelProgram\x18\x02 \x01(\x0b\x32\x17.qm.grpc.qua.QuaProgram\"e\n\x0f\x43ompileResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\x11\n\tprogramId\x18\x02 \x01(\t\x12\x33\n\x08messages\x18\x03 \x03(\x0b\x32!.qm.grpc.compiler.CompilerMessage\"G\n\x1cGetJobExecutionStatusRequest\x12\x18\n\x10quantumMachineId\x18\x01 \x01(\t\x12\r\n\x05jobId\x18\x02 \x01(\t\"U\n\x1dGetJobExecutionStatusResponse\x12\x34\n\x06status\x18\x01 \x01(\x0b\x32$.qm.grpc.frontend.JobExecutionStatus\"\x90\x08\n\x12JobExecutionStatus\x12?\n\x07unknown\x18\x01 \x01(\x0b\x32,.qm.grpc.frontend.JobExecutionStatus.UnknownH\x00\x12?\n\x07pending\x18\x02 \x01(\x0b\x32,.qm.grpc.frontend.JobExecutionStatus.PendingH\x00\x12?\n\x07running\x18\x03 \x01(\x0b\x32,.qm.grpc.frontend.JobExecutionStatus.RunningH\x00\x12\x43\n\tcompleted\x18\x04 \x01(\x0b\x32..qm.grpc.frontend.JobExecutionStatus.CompletedH\x00\x12\x41\n\x08\x63\x61nceled\x18\x05 \x01(\x0b\x32-.qm.grpc.frontend.JobExecutionStatus.CanceledH\x00\x12?\n\x07loading\x18\x06 \x01(\x0b\x32,.qm.grpc.frontend.JobExecutionStatus.LoadingH\x00\x1a\t\n\x07Unknown\x1a\x62\n\x07Pending\x12\x17\n\x0fpositionInQueue\x18\x01 \x01(\x05\x12-\n\ttimeAdded\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61\x64\x64\x65\x64\x42y\x18\x03 \x01(\t\x1az\n\x07Running\x12-\n\ttimeAdded\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61\x64\x64\x65\x64\x42y\x18\x02 \x01(\t\x12/\n\x0btimeStarted\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xaf\x01\n\tCompleted\x12-\n\ttimeAdded\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61\x64\x64\x65\x64\x42y\x18\x02 \x01(\t\x12/\n\x0btimeStarted\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rtimeCompleted\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a|\n\x08\x43\x61nceled\x12-\n\ttimeAdded\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61\x64\x64\x65\x64\x42y\x18\x02 \x01(\t\x12\x30\n\x0ctimeCanceled\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1aI\n\x07Loading\x12-\n\ttimeAdded\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61\x64\x64\x65\x64\x42y\x18\x02 \x01(\tB\x08\n\x06status\"\xca\x01\n\x16GetPendingJobsResponse\x12N\n\x0bpendingJobs\x18\x01 \x03(\x0b\x32\x39.qm.grpc.frontend.GetPendingJobsResponse.PendingJobsEntry\x1a`\n\x10PendingJobsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.qm.grpc.frontend.JobExecutionStatus.Pending:\x02\x38\x01\"\xc3\x01\n\x0eJobQueryParams\x12\x18\n\x10quantumMachineId\x18\x01 \x01(\t\x12\x32\n\x05jobId\x18\x02 \x01(\x0b\x32#.qm.grpc.frontend.QueryValueMatcher\x12\x33\n\x06userId\x18\x03 \x01(\x0b\x32#.qm.grpc.frontend.QueryValueMatcher\x12.\n\x08position\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\"@\n\x11QueryValueMatcher\x12\r\n\x03\x61ny\x18\x01 \x01(\x08H\x00\x12\x0f\n\x05value\x18\x02 \x01(\tH\x00\x42\x0b\n\tvalueType\"9\n\x19RemovePendingJobsResponse\x12\x1c\n\x14numbersOfJobsRemoved\x18\x01 \x01(\x05\"\xf9\x01\n\x11SimulationRequest\x12-\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfig\x12\x31\n\x10highLevelProgram\x18\x02 \x01(\x0b\x32\x17.qm.grpc.qua.QuaProgram\x12=\n\x08simulate\x18\x03 \x01(\x0b\x32+.qm.grpc.frontend.ExecutionRequest.Simulate\x12\x43\n\x15\x63ontrollerConnections\x18\x06 \x03(\x0b\x32$.qm.grpc.frontend.InterOpxConnection\"3\n\x0fInterOpxAddress\x12\x12\n\ncontroller\x18\x01 \x01(\t\x12\x0c\n\x04left\x18\x02 \x01(\x08\"O\n\x0eInterOpxTarget\x12\x33\n\x06\x64irect\x18\x01 \x01(\x0b\x32!.qm.grpc.frontend.InterOpxAddressH\x00\x42\x08\n\x06target\"<\n\x0fInterOpxChannel\x12\x12\n\ncontroller\x18\x01 \x01(\t\x12\x15\n\rchannelNumber\x18\x02 \x01(\x05\"\xad\x04\n\x12InterOpxConnection\x12\x35\n\x06source\x18\x01 \x01(\x0b\x32!.qm.grpc.frontend.InterOpxAddressB\x02\x18\x01\x12\x34\n\x06target\x18\x02 \x01(\x0b\x32 .qm.grpc.frontend.InterOpxTargetB\x02\x18\x01\x12Q\n\x10\x61\x64\x64ressToAddress\x18\x03 \x01(\x0b\x32\x35.qm.grpc.frontend.InterOpxConnection.AddressToAddressH\x00\x12Q\n\x10\x63hannelToChannel\x18\x04 \x01(\x0b\x32\x35.qm.grpc.frontend.InterOpxConnection.ChannelToChannelH\x00\x1ax\n\x10\x41\x64\x64ressToAddress\x12\x31\n\x06source\x18\x01 \x01(\x0b\x32!.qm.grpc.frontend.InterOpxAddress\x12\x31\n\x06target\x18\x02 \x01(\x0b\x32!.qm.grpc.frontend.InterOpxAddress\x1ax\n\x10\x43hannelToChannel\x12\x31\n\x06source\x18\x01 \x01(\x0b\x32!.qm.grpc.frontend.InterOpxChannel\x12\x31\n\x06target\x18\x02 \x01(\x0b\x32!.qm.grpc.frontend.InterOpxChannelB\x10\n\x0e\x63onnectionType\"\xc3\x02\n\x12SimulationResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05jobId\x18\x02 \x01(\t\x12K\n\x16\x63onfigValidationErrors\x18\x03 \x03(\x0b\x32+.qm.grpc.qm_manager.ConfigValidationMessage\x12O\n\x18physicalValidationErrors\x18\x04 \x03(\x0b\x32-.qm.grpc.qm_manager.PhysicalValidationMessage\x12\x33\n\x08messages\x18\x05 \x03(\x0b\x32!.qm.grpc.compiler.CompilerMessage\x12:\n\tsimulated\x18\x06 \x01(\x0b\x32\'.qm.grpc.frontend.SimulatedResponsePart\"$\n\x13IsJobRunningRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"8\n\x14IsJobRunningResponse\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x11\n\tisRunning\x18\x02 \x01(\x08\"*\n\x19IsJobAcquiringDataRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"\xdb\x01\n\x1aIsJobAcquiringDataResponse\x12\r\n\x05jobId\x18\x01 \x01(\t\x12U\n\x0f\x61\x63quiringStatus\x18\x02 \x01(\x0e\x32<.qm.grpc.frontend.IsJobAcquiringDataResponse.AcquiringStatus\"W\n\x0f\x41\x63quiringStatus\x12\x13\n\x0f\x41\x43QUIRE_STOPPED\x10\x00\x12\x16\n\x12NO_DATA_TO_ACQUIRE\x10\x01\x12\x17\n\x13HAS_DATA_TO_ACQUIRE\x10\x02\"K\n\rQmDataRequest\x12:\n\x10io_value_Request\x18\x01 \x03(\x0b\x32 .qm.grpc.frontend.IOValueRequest\"\x99\x02\n\x0eQmDataResponse\x12K\n\x11io_value_response\x18\x01 \x03(\x0b\x32\x30.qm.grpc.frontend.QmDataResponse.IOValueResponse\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x36\n\x06\x65rrors\x18\x03 \x03(\x0b\x32&.qm.grpc.general_messages.ErrorMessage\x1aq\n\x0fIOValueResponse\x12\x31\n\x07request\x18\x01 \x01(\x0b\x32 .qm.grpc.frontend.IOValueRequest\x12+\n\x06values\x18\x02 \x01(\x0b\x32\x1b.qm.grpc.compiler.QuaValues\"\x80\x01\n\x0eIOValueRequest\x12\x19\n\rpulser_number\x18\x01 \x01(\rB\x02\x18\x01\x12\x11\n\tio_number\x18\x02 \x01(\r\x12\x0f\n\x05jobId\x18\x03 \x01(\tH\x00\x12\x1a\n\x10quantumMachineId\x18\x04 \x01(\tH\x00\x42\x13\n\x11identifier_one_of\"9\n\rResumeRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x19\n\rpulsersBitmap\x18\x02 \x01(\rB\x02\x18\x01\"\x10\n\x0eResumeResponse\"$\n\x13PausedStatusRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"O\n\x14PausedStatusResponse\x12\x19\n\rpulsersBitmap\x18\x01 \x01(\rB\x02\x18\x01\x12\n\n\x02ok\x18\x02 \x01(\x08\x12\x10\n\x08isPaused\x18\x03 \x01(\x08\"\"\n\x11PullResultRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"=\n\x1aPullAnalysedResultsRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x10\n\x08metadata\x18\x02 \x01(\t\"\x94\x01\n\x12PullResultResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12\x11\n\tbytesLeft\x18\x03 \x01(\r\x12\x16\n\x0e\x63ontrollerName\x18\x04 \x01(\t\x12\x19\n\x11\x61pplicationNumber\x18\x05 \x01(\r\x12\x1a\n\x12implementationName\x18\x06 \x01(\t\"b\n\x13HealthCheckResponse\x12\x0f\n\x07message\x18\x01 \x03(\t\x12\n\n\x02ok\x18\x02 \x01(\x08\x12\x15\n\rerrorMessages\x18\x03 \x03(\t\x12\x17\n\x0fwarningMessages\x18\x04 \x03(\t\"\x80\x11\n\x10\x45xecutionRequest\x12\x33\n\x10highLevelProgram\x18\x01 \x01(\x0b\x32\x17.qm.grpc.qua.QuaProgramH\x00\x12\x1d\n\x0flowLevelProgram\x18\x02 \x01(\x0c\x42\x02\x18\x01H\x00\x12\x1b\n\x13streamDurationLimit\x18\x03 \x01(\r\x12\x17\n\x0fstreamDataLimit\x18\x04 \x01(\r\x12\x16\n\x0e\x66orceExecution\x18\x05 \x01(\x08\x12=\n\x08simulate\x18\x06 \x01(\x0b\x32+.qm.grpc.frontend.ExecutionRequest.Simulate\x12\x0e\n\x06\x64ryRun\x18\x07 \x01(\x08\x12\x18\n\x10quantumMachineId\x18\x08 \x01(\t\x1a\xce\x0e\n\x08Simulate\x12\x10\n\x08\x64uration\x18\x01 \x01(\r\x12!\n\x15simulateAnalogOutputs\x18\x02 \x01(\x08\x42\x02\x18\x01\x12\"\n\x16simulateDigitalOutputs\x18\x03 \x01(\x08\x42\x02\x18\x01\x12 \n\x14includeAnalogSamples\x18\x04 \x01(\x08\x42\x02\x18\x01\x12!\n\x15includeDigitalSamples\x18\x05 \x01(\x08\x42\x02\x18\x01\x12\x1e\n\x16includeAnalogWaveforms\x18\x06 \x01(\x08\x12\x1f\n\x17includeDigitalWaveforms\x18\x07 \x01(\x08\x12\\\n\x13simulationInterface\x18\x08 \x01(\x0b\x32?.qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface\x12 \n\x18\x65xtraProcessingTimeoutMs\x18\t \x01(\x05\x1a\xe2\x0b\n\x13SimulationInterface\x12T\n\x04none\x18\x01 \x01(\x0b\x32\x44.qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.NoneH\x00\x12\\\n\x08loopback\x18\x02 \x01(\x0b\x32H.qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.LoopbackH\x00\x12T\n\x04qsim\x18\x03 \x01(\x0b\x32\x44.qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QSimH\x00\x12[\n\x03raw\x18\x04 \x01(\x0b\x32L.qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.RawInterfaceH\x00\x12v\n\x11quantum_simulator\x18\x05 \x01(\x0b\x32Y.qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QuantumSimulatorInterfaceH\x00\x1a\x06\n\x04None\x1a\xf9\x01\n\x08Loopback\x12i\n\x0b\x63onnections\x18\x02 \x03(\x0b\x32T.qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.Loopback.Connections\x12\x0f\n\x07latency\x18\x03 \x01(\r\x12\x12\n\nnoisePower\x18\x04 \x01(\x01\x1a]\n\x0b\x43onnections\x12\x16\n\x0e\x66romController\x18\x01 \x01(\t\x12\x10\n\x08\x66romPort\x18\x02 \x01(\x05\x12\x14\n\x0ctoController\x18\x03 \x01(\t\x12\x0e\n\x06toPort\x18\x04 \x01(\x05\x1a\xbe\x03\n\x04QSim\x12\x0e\n\x06target\x18\x01 \x01(\t\x12\r\n\x05jobId\x18\x02 \x01(\t\x12n\n\x14\x61nalogOutConnections\x18\x03 \x03(\x0b\x32P.qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QSim.Connections\x12o\n\x15\x64igitalOutConnections\x18\x04 \x03(\x0b\x32P.qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QSim.Connections\x12m\n\x13\x61nalogInConnections\x18\x05 \x03(\x0b\x32P.qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QSim.Connections\x1aG\n\x0b\x43onnections\x12\x16\n\x0e\x66romController\x18\x01 \x01(\t\x12\x10\n\x08\x66romPort\x18\x02 \x01(\x05\x12\x0e\n\x06toQSim\x18\x03 \x01(\t\x1a\x34\n\x19QuantumSimulatorInterface\x12\x17\n\x0fphysical_config\x18\x01 \x01(\x0c\x1a\xdd\x01\n\x0cRawInterface\x12m\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32X.qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.RawInterface.Connections\x12\x12\n\nnoisePower\x18\x02 \x01(\x01\x1aJ\n\x0b\x43onnections\x12\x16\n\x0e\x66romController\x18\x01 \x01(\t\x12\x10\n\x08\x66romPort\x18\x02 \x01(\x05\x12\x11\n\ttoSamples\x18\x03 \x03(\x01\x42\x11\n\x0finterface_oneofB\x10\n\x0eprogram_one_of\"\xe0\x01\n\x11\x45xecutionResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\r\n\x05jobId\x18\x02 \x01(\t\x12\x33\n\x08messages\x18\x03 \x03(\x0b\x32!.qm.grpc.compiler.CompilerMessage\x12\x10\n\x08metadata\x18\x04 \x01(\t\x12:\n\tsimulated\x18\x06 \x01(\x0b\x32\'.qm.grpc.frontend.SimulatedResponsePart\x12-\n\x06\x63onfig\x18\x07 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfig\"\x88\x01\n\x15SimulatedResponsePart\x12.\n\ranalogOutputs\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12/\n\x0e\x64igitalOutputs\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06\x65rrors\x18\x03 \x03(\t\"\x1c\n\x1aResetDataProcessingRequest\"\x1d\n\x1bResetDataProcessingResponse\"\x1c\n\x0bHaltRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"\x1a\n\x0cHaltResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\"4\n\x0bPeekRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\r\x12\x14\n\x0c\x63ontrollerId\x18\x02 \x01(\t\"\x1d\n\x0cPeekResponse\x12\r\n\x05value\x18\x01 \x01(\r\"C\n\x0bPokeRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r\x12\x14\n\x0c\x63ontrollerId\x18\x03 \x01(\t\"\x1a\n\x0cPokeResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\"0\n\x1fGetSimulatedQuantumStateRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"m\n GetSimulatedQuantumStateResponse\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\n\n\x02ok\x18\x02 \x01(\x08\x12.\n\x05state\x18\x03 \x01(\x0b\x32\x1f.qm.grpc.frontend.DensityMatrix\"Q\n\rDensityMatrix\x12\x11\n\ttimeStamp\x18\x01 \x01(\x04\x12-\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x1f.qm.grpc.frontend.ComplexNumber\"\'\n\rComplexNumber\x12\n\n\x02re\x18\x01 \x01(\x01\x12\n\n\x02im\x18\x02 \x01(\x01\"H\n\x1dPerformHalDebugCommandRequest\x12\x16\n\x0e\x63ontrollerName\x18\x01 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\"C\n\x1ePerformHalDebugCommandResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x10\n\x08response\x18\x02 \x01(\t2\x84\x18\n\x08\x46rontend\x12\x44\n\nGetVersion\x12\x16.google.protobuf.Empty\x1a\x1c.google.protobuf.StringValue\"\x00\x12N\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a%.qm.grpc.frontend.HealthCheckResponse\"\x00\x12T\n\x07\x45xecute\x12\".qm.grpc.frontend.ExecutionRequest\x1a#.qm.grpc.frontend.ExecutionResponse\"\x00\x12Y\n\nAddToQueue\x12#.qm.grpc.frontend.AddToQueueRequest\x1a$.qm.grpc.frontend.AddToQueueResponse\"\x00\x12P\n\x07\x43ompile\x12 .qm.grpc.frontend.CompileRequest\x1a!.qm.grpc.frontend.CompileResponse\"\x00\x12q\n\x12\x41\x64\x64\x43ompiledToQueue\x12+.qm.grpc.frontend.AddCompiledToQueueRequest\x1a,.qm.grpc.frontend.AddCompiledToQueueResponse\"\x00\x12\x64\n\x11RemovePendingJobs\x12 .qm.grpc.frontend.JobQueryParams\x1a+.qm.grpc.frontend.RemovePendingJobsResponse\"\x00\x12^\n\x0eGetPendingJobs\x12 .qm.grpc.frontend.JobQueryParams\x1a(.qm.grpc.frontend.GetPendingJobsResponse\"\x00\x12z\n\x15GetJobExecutionStatus\x12..qm.grpc.frontend.GetJobExecutionStatusRequest\x1a/.qm.grpc.frontend.GetJobExecutionStatusResponse\"\x00\x12_\n\x0cPausedStatus\x12%.qm.grpc.frontend.PausedStatusRequest\x1a&.qm.grpc.frontend.PausedStatusResponse\"\x00\x12M\n\x06Resume\x12\x1f.qm.grpc.frontend.ResumeRequest\x1a .qm.grpc.frontend.ResumeResponse\"\x00\x12G\n\x04Halt\x12\x1d.qm.grpc.frontend.HaltRequest\x1a\x1e.qm.grpc.frontend.HaltResponse\"\x00\x12t\n\x13ResetDataProcessing\x12,.qm.grpc.frontend.ResetDataProcessingRequest\x1a-.qm.grpc.frontend.ResetDataProcessingResponse\"\x00\x12W\n\x0eValidateConfig\x12\x1d.qm.grpc.qua_config.QuaConfig\x1a$.qm.grpc.compiler.ValidationResponse\"\x00\x12\x38\n\x04Init\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12Y\n\x10PerformQmRequest\x12 .qm.grpc.qm_api.HighQmApiRequest\x1a!.qm.grpc.qm_api.HighQmApiResponse\"\x00\x12R\n\x0bRequestData\x12\x1f.qm.grpc.frontend.QmDataRequest\x1a .qm.grpc.frontend.QmDataResponse\"\x00\x12\x85\x01\n\x14PullSimulatorSamples\x12\x35.qm.grpc.results_analyser.PullSimulatorSamplesRequest\x1a\x32.qm.grpc.results_analyser.SimulatorSamplesResponse\"\x00\x30\x01\x12u\n\x12OpenQuantumMachine\x12-.qm.grpc.qm_manager.OpenQuantumMachineRequest\x1a..qm.grpc.qm_manager.OpenQuantumMachineResponse\"\x00\x12x\n\x13\x43loseQuantumMachine\x12..qm.grpc.qm_manager.CloseQuantumMachineRequest\x1a/.qm.grpc.qm_manager.CloseQuantumMachineResponse\"\x00\x12r\n\x11GetQuantumMachine\x12,.qm.grpc.qm_manager.GetQuantumMachineRequest\x1a-.qm.grpc.qm_manager.GetQuantumMachineResponse\"\x00\x12\x66\n\rGetRunningJob\x12(.qm.grpc.qm_manager.GetRunningJobRequest\x1a).qm.grpc.qm_manager.GetRunningJobResponse\"\x00\x12h\n\x17ListOpenQuantumMachines\x12\x16.google.protobuf.Empty\x1a\x33.qm.grpc.qm_manager.ListOpenQuantumMachinesResponse\"\x00\x12h\n\x17\x43loseAllQuantumMachines\x12\x16.google.protobuf.Empty\x1a\x33.qm.grpc.qm_manager.CloseAllQuantumMachinesResponse\"\x00\x12V\n\x0eGetControllers\x12\x16.google.protobuf.Empty\x1a*.qm.grpc.qm_manager.GetControllersResponse\"\x00\x12_\n\x0cIsJobRunning\x12%.qm.grpc.frontend.IsJobRunningRequest\x1a&.qm.grpc.frontend.IsJobRunningResponse\"\x00\x12q\n\x12IsJobAcquiringData\x12+.qm.grpc.frontend.IsJobAcquiringDataRequest\x1a,.qm.grpc.frontend.IsJobAcquiringDataResponse\"\x00\x12W\n\x08Simulate\x12#.qm.grpc.frontend.SimulationRequest\x1a$.qm.grpc.frontend.SimulationResponse\"\x00\x12\x46\n\x12\x43learAllJobResults\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12}\n\x16PerformHalDebugCommand\x12/.qm.grpc.frontend.PerformHalDebugCommandRequest\x1a\x30.qm.grpc.frontend.PerformHalDebugCommandResponse\"\x00\x12\x83\x01\n\x18GetSimulatedQuantumState\x12\x31.qm.grpc.frontend.GetSimulatedQuantumStateRequest\x1a\x32.qm.grpc.frontend.GetSimulatedQuantumStateResponse\"\x00\x42)\n\x10qm.grpc.frontendB\rFrontendProtoP\x01\xa2\x02\x03HLWb\x06proto3'
  ,
  dependencies=[qm_dot_pb_dot_inc__qua__pb2.DESCRIPTOR,qm_dot_pb_dot_inc__qua__config__pb2.DESCRIPTOR,qm_dot_pb_dot_inc__qm__api__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,qm_dot_pb_dot_compiler__pb2.DESCRIPTOR,qm_dot_pb_dot_job__results__pb2.DESCRIPTOR,qm_dot_pb_dot_qm__manager__pb2.DESCRIPTOR,qm_dot_pb_dot_general__messages__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_ISJOBACQUIRINGDATARESPONSE_ACQUIRINGSTATUS = _descriptor.EnumDescriptor(
  name='AcquiringStatus',
  full_name='qm.grpc.frontend.IsJobAcquiringDataResponse.AcquiringStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACQUIRE_STOPPED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_DATA_TO_ACQUIRE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HAS_DATA_TO_ACQUIRE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4770,
  serialized_end=4857,
)
_sym_db.RegisterEnumDescriptor(_ISJOBACQUIRINGDATARESPONSE_ACQUIRINGSTATUS)


_QUEUEPOSITION = _descriptor.Descriptor(
  name='QueuePosition',
  full_name='qm.grpc.frontend.QueuePosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='end', full_name='qm.grpc.frontend.QueuePosition.end', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='qm.grpc.frontend.QueuePosition.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='position', full_name='qm.grpc.frontend.QueuePosition.position',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=340,
  serialized_end=447,
)


_ADDTOQUEUEREQUEST = _descriptor.Descriptor(
  name='AddToQueueRequest',
  full_name='qm.grpc.frontend.AddToQueueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='quantumMachineId', full_name='qm.grpc.frontend.AddToQueueRequest.quantumMachineId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='highLevelProgram', full_name='qm.grpc.frontend.AddToQueueRequest.highLevelProgram', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queuePosition', full_name='qm.grpc.frontend.AddToQueueRequest.queuePosition', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=450,
  serialized_end=602,
)


_ADDTOQUEUERESPONSE = _descriptor.Descriptor(
  name='AddToQueueResponse',
  full_name='qm.grpc.frontend.AddToQueueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='qm.grpc.frontend.AddToQueueResponse.ok', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.AddToQueueResponse.jobId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='qm.grpc.frontend.AddToQueueResponse.messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=604,
  serialized_end=704,
)


_WAVEFORMOVERRIDE = _descriptor.Descriptor(
  name='WaveformOverride',
  full_name='qm.grpc.frontend.WaveformOverride',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='samples', full_name='qm.grpc.frontend.WaveformOverride.samples', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=706,
  serialized_end=741,
)


_EXECUTIONOVERRIDES_WAVEFORMSENTRY = _descriptor.Descriptor(
  name='WaveformsEntry',
  full_name='qm.grpc.frontend.ExecutionOverrides.WaveformsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.frontend.ExecutionOverrides.WaveformsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.frontend.ExecutionOverrides.WaveformsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=838,
  serialized_end=922,
)

_EXECUTIONOVERRIDES = _descriptor.Descriptor(
  name='ExecutionOverrides',
  full_name='qm.grpc.frontend.ExecutionOverrides',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='waveforms', full_name='qm.grpc.frontend.ExecutionOverrides.waveforms', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXECUTIONOVERRIDES_WAVEFORMSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=744,
  serialized_end=922,
)


_ADDCOMPILEDTOQUEUEREQUEST = _descriptor.Descriptor(
  name='AddCompiledToQueueRequest',
  full_name='qm.grpc.frontend.AddCompiledToQueueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='quantumMachineId', full_name='qm.grpc.frontend.AddCompiledToQueueRequest.quantumMachineId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='programId', full_name='qm.grpc.frontend.AddCompiledToQueueRequest.programId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queuePosition', full_name='qm.grpc.frontend.AddCompiledToQueueRequest.queuePosition', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executionOverrides', full_name='qm.grpc.frontend.AddCompiledToQueueRequest.executionOverrides', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=925,
  serialized_end=1119,
)


_ADDCOMPILEDTOQUEUERESPONSE = _descriptor.Descriptor(
  name='AddCompiledToQueueResponse',
  full_name='qm.grpc.frontend.AddCompiledToQueueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='qm.grpc.frontend.AddCompiledToQueueResponse.ok', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.AddCompiledToQueueResponse.jobId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errors', full_name='qm.grpc.frontend.AddCompiledToQueueResponse.errors', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1121,
  serialized_end=1232,
)


_COMPILEREQUEST = _descriptor.Descriptor(
  name='CompileRequest',
  full_name='qm.grpc.frontend.CompileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='quantumMachineId', full_name='qm.grpc.frontend.CompileRequest.quantumMachineId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='highLevelProgram', full_name='qm.grpc.frontend.CompileRequest.highLevelProgram', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1234,
  serialized_end=1327,
)


_COMPILERESPONSE = _descriptor.Descriptor(
  name='CompileResponse',
  full_name='qm.grpc.frontend.CompileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='qm.grpc.frontend.CompileResponse.ok', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='programId', full_name='qm.grpc.frontend.CompileResponse.programId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='qm.grpc.frontend.CompileResponse.messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1329,
  serialized_end=1430,
)


_GETJOBEXECUTIONSTATUSREQUEST = _descriptor.Descriptor(
  name='GetJobExecutionStatusRequest',
  full_name='qm.grpc.frontend.GetJobExecutionStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='quantumMachineId', full_name='qm.grpc.frontend.GetJobExecutionStatusRequest.quantumMachineId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.GetJobExecutionStatusRequest.jobId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1432,
  serialized_end=1503,
)


_GETJOBEXECUTIONSTATUSRESPONSE = _descriptor.Descriptor(
  name='GetJobExecutionStatusResponse',
  full_name='qm.grpc.frontend.GetJobExecutionStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='qm.grpc.frontend.GetJobExecutionStatusResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1505,
  serialized_end=1590,
)


_JOBEXECUTIONSTATUS_UNKNOWN = _descriptor.Descriptor(
  name='Unknown',
  full_name='qm.grpc.frontend.JobExecutionStatus.Unknown',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2011,
  serialized_end=2020,
)

_JOBEXECUTIONSTATUS_PENDING = _descriptor.Descriptor(
  name='Pending',
  full_name='qm.grpc.frontend.JobExecutionStatus.Pending',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='positionInQueue', full_name='qm.grpc.frontend.JobExecutionStatus.Pending.positionInQueue', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeAdded', full_name='qm.grpc.frontend.JobExecutionStatus.Pending.timeAdded', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addedBy', full_name='qm.grpc.frontend.JobExecutionStatus.Pending.addedBy', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2022,
  serialized_end=2120,
)

_JOBEXECUTIONSTATUS_RUNNING = _descriptor.Descriptor(
  name='Running',
  full_name='qm.grpc.frontend.JobExecutionStatus.Running',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeAdded', full_name='qm.grpc.frontend.JobExecutionStatus.Running.timeAdded', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addedBy', full_name='qm.grpc.frontend.JobExecutionStatus.Running.addedBy', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeStarted', full_name='qm.grpc.frontend.JobExecutionStatus.Running.timeStarted', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2122,
  serialized_end=2244,
)

_JOBEXECUTIONSTATUS_COMPLETED = _descriptor.Descriptor(
  name='Completed',
  full_name='qm.grpc.frontend.JobExecutionStatus.Completed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeAdded', full_name='qm.grpc.frontend.JobExecutionStatus.Completed.timeAdded', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addedBy', full_name='qm.grpc.frontend.JobExecutionStatus.Completed.addedBy', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeStarted', full_name='qm.grpc.frontend.JobExecutionStatus.Completed.timeStarted', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeCompleted', full_name='qm.grpc.frontend.JobExecutionStatus.Completed.timeCompleted', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2247,
  serialized_end=2422,
)

_JOBEXECUTIONSTATUS_CANCELED = _descriptor.Descriptor(
  name='Canceled',
  full_name='qm.grpc.frontend.JobExecutionStatus.Canceled',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeAdded', full_name='qm.grpc.frontend.JobExecutionStatus.Canceled.timeAdded', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addedBy', full_name='qm.grpc.frontend.JobExecutionStatus.Canceled.addedBy', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeCanceled', full_name='qm.grpc.frontend.JobExecutionStatus.Canceled.timeCanceled', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2424,
  serialized_end=2548,
)

_JOBEXECUTIONSTATUS_LOADING = _descriptor.Descriptor(
  name='Loading',
  full_name='qm.grpc.frontend.JobExecutionStatus.Loading',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeAdded', full_name='qm.grpc.frontend.JobExecutionStatus.Loading.timeAdded', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addedBy', full_name='qm.grpc.frontend.JobExecutionStatus.Loading.addedBy', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2550,
  serialized_end=2623,
)

_JOBEXECUTIONSTATUS = _descriptor.Descriptor(
  name='JobExecutionStatus',
  full_name='qm.grpc.frontend.JobExecutionStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unknown', full_name='qm.grpc.frontend.JobExecutionStatus.unknown', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending', full_name='qm.grpc.frontend.JobExecutionStatus.pending', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='running', full_name='qm.grpc.frontend.JobExecutionStatus.running', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='completed', full_name='qm.grpc.frontend.JobExecutionStatus.completed', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='canceled', full_name='qm.grpc.frontend.JobExecutionStatus.canceled', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loading', full_name='qm.grpc.frontend.JobExecutionStatus.loading', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_JOBEXECUTIONSTATUS_UNKNOWN, _JOBEXECUTIONSTATUS_PENDING, _JOBEXECUTIONSTATUS_RUNNING, _JOBEXECUTIONSTATUS_COMPLETED, _JOBEXECUTIONSTATUS_CANCELED, _JOBEXECUTIONSTATUS_LOADING, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='qm.grpc.frontend.JobExecutionStatus.status',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1593,
  serialized_end=2633,
)


_GETPENDINGJOBSRESPONSE_PENDINGJOBSENTRY = _descriptor.Descriptor(
  name='PendingJobsEntry',
  full_name='qm.grpc.frontend.GetPendingJobsResponse.PendingJobsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='qm.grpc.frontend.GetPendingJobsResponse.PendingJobsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.frontend.GetPendingJobsResponse.PendingJobsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2742,
  serialized_end=2838,
)

_GETPENDINGJOBSRESPONSE = _descriptor.Descriptor(
  name='GetPendingJobsResponse',
  full_name='qm.grpc.frontend.GetPendingJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pendingJobs', full_name='qm.grpc.frontend.GetPendingJobsResponse.pendingJobs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETPENDINGJOBSRESPONSE_PENDINGJOBSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2636,
  serialized_end=2838,
)


_JOBQUERYPARAMS = _descriptor.Descriptor(
  name='JobQueryParams',
  full_name='qm.grpc.frontend.JobQueryParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='quantumMachineId', full_name='qm.grpc.frontend.JobQueryParams.quantumMachineId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.JobQueryParams.jobId', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='qm.grpc.frontend.JobQueryParams.userId', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='qm.grpc.frontend.JobQueryParams.position', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2841,
  serialized_end=3036,
)


_QUERYVALUEMATCHER = _descriptor.Descriptor(
  name='QueryValueMatcher',
  full_name='qm.grpc.frontend.QueryValueMatcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='any', full_name='qm.grpc.frontend.QueryValueMatcher.any', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.frontend.QueryValueMatcher.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='valueType', full_name='qm.grpc.frontend.QueryValueMatcher.valueType',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3038,
  serialized_end=3102,
)


_REMOVEPENDINGJOBSRESPONSE = _descriptor.Descriptor(
  name='RemovePendingJobsResponse',
  full_name='qm.grpc.frontend.RemovePendingJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='numbersOfJobsRemoved', full_name='qm.grpc.frontend.RemovePendingJobsResponse.numbersOfJobsRemoved', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3104,
  serialized_end=3161,
)


_SIMULATIONREQUEST = _descriptor.Descriptor(
  name='SimulationRequest',
  full_name='qm.grpc.frontend.SimulationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='qm.grpc.frontend.SimulationRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='highLevelProgram', full_name='qm.grpc.frontend.SimulationRequest.highLevelProgram', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulate', full_name='qm.grpc.frontend.SimulationRequest.simulate', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controllerConnections', full_name='qm.grpc.frontend.SimulationRequest.controllerConnections', index=3,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3164,
  serialized_end=3413,
)


_INTEROPXADDRESS = _descriptor.Descriptor(
  name='InterOpxAddress',
  full_name='qm.grpc.frontend.InterOpxAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='controller', full_name='qm.grpc.frontend.InterOpxAddress.controller', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left', full_name='qm.grpc.frontend.InterOpxAddress.left', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3415,
  serialized_end=3466,
)


_INTEROPXTARGET = _descriptor.Descriptor(
  name='InterOpxTarget',
  full_name='qm.grpc.frontend.InterOpxTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='direct', full_name='qm.grpc.frontend.InterOpxTarget.direct', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target', full_name='qm.grpc.frontend.InterOpxTarget.target',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3468,
  serialized_end=3547,
)


_INTEROPXCHANNEL = _descriptor.Descriptor(
  name='InterOpxChannel',
  full_name='qm.grpc.frontend.InterOpxChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='controller', full_name='qm.grpc.frontend.InterOpxChannel.controller', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channelNumber', full_name='qm.grpc.frontend.InterOpxChannel.channelNumber', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3549,
  serialized_end=3609,
)


_INTEROPXCONNECTION_ADDRESSTOADDRESS = _descriptor.Descriptor(
  name='AddressToAddress',
  full_name='qm.grpc.frontend.InterOpxConnection.AddressToAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='qm.grpc.frontend.InterOpxConnection.AddressToAddress.source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='qm.grpc.frontend.InterOpxConnection.AddressToAddress.target', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3909,
  serialized_end=4029,
)

_INTEROPXCONNECTION_CHANNELTOCHANNEL = _descriptor.Descriptor(
  name='ChannelToChannel',
  full_name='qm.grpc.frontend.InterOpxConnection.ChannelToChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='qm.grpc.frontend.InterOpxConnection.ChannelToChannel.source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='qm.grpc.frontend.InterOpxConnection.ChannelToChannel.target', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4031,
  serialized_end=4151,
)

_INTEROPXCONNECTION = _descriptor.Descriptor(
  name='InterOpxConnection',
  full_name='qm.grpc.frontend.InterOpxConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='qm.grpc.frontend.InterOpxConnection.source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='qm.grpc.frontend.InterOpxConnection.target', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addressToAddress', full_name='qm.grpc.frontend.InterOpxConnection.addressToAddress', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channelToChannel', full_name='qm.grpc.frontend.InterOpxConnection.channelToChannel', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INTEROPXCONNECTION_ADDRESSTOADDRESS, _INTEROPXCONNECTION_CHANNELTOCHANNEL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='connectionType', full_name='qm.grpc.frontend.InterOpxConnection.connectionType',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3612,
  serialized_end=4169,
)


_SIMULATIONRESPONSE = _descriptor.Descriptor(
  name='SimulationResponse',
  full_name='qm.grpc.frontend.SimulationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='qm.grpc.frontend.SimulationResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.SimulationResponse.jobId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configValidationErrors', full_name='qm.grpc.frontend.SimulationResponse.configValidationErrors', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='physicalValidationErrors', full_name='qm.grpc.frontend.SimulationResponse.physicalValidationErrors', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='qm.grpc.frontend.SimulationResponse.messages', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulated', full_name='qm.grpc.frontend.SimulationResponse.simulated', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4172,
  serialized_end=4495,
)


_ISJOBRUNNINGREQUEST = _descriptor.Descriptor(
  name='IsJobRunningRequest',
  full_name='qm.grpc.frontend.IsJobRunningRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.IsJobRunningRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4497,
  serialized_end=4533,
)


_ISJOBRUNNINGRESPONSE = _descriptor.Descriptor(
  name='IsJobRunningResponse',
  full_name='qm.grpc.frontend.IsJobRunningResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.IsJobRunningResponse.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isRunning', full_name='qm.grpc.frontend.IsJobRunningResponse.isRunning', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4535,
  serialized_end=4591,
)


_ISJOBACQUIRINGDATAREQUEST = _descriptor.Descriptor(
  name='IsJobAcquiringDataRequest',
  full_name='qm.grpc.frontend.IsJobAcquiringDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.IsJobAcquiringDataRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4593,
  serialized_end=4635,
)


_ISJOBACQUIRINGDATARESPONSE = _descriptor.Descriptor(
  name='IsJobAcquiringDataResponse',
  full_name='qm.grpc.frontend.IsJobAcquiringDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.IsJobAcquiringDataResponse.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acquiringStatus', full_name='qm.grpc.frontend.IsJobAcquiringDataResponse.acquiringStatus', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ISJOBACQUIRINGDATARESPONSE_ACQUIRINGSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4638,
  serialized_end=4857,
)


_QMDATAREQUEST = _descriptor.Descriptor(
  name='QmDataRequest',
  full_name='qm.grpc.frontend.QmDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='io_value_Request', full_name='qm.grpc.frontend.QmDataRequest.io_value_Request', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4859,
  serialized_end=4934,
)


_QMDATARESPONSE_IOVALUERESPONSE = _descriptor.Descriptor(
  name='IOValueResponse',
  full_name='qm.grpc.frontend.QmDataResponse.IOValueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='qm.grpc.frontend.QmDataResponse.IOValueResponse.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='qm.grpc.frontend.QmDataResponse.IOValueResponse.values', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5105,
  serialized_end=5218,
)

_QMDATARESPONSE = _descriptor.Descriptor(
  name='QmDataResponse',
  full_name='qm.grpc.frontend.QmDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='io_value_response', full_name='qm.grpc.frontend.QmDataResponse.io_value_response', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success', full_name='qm.grpc.frontend.QmDataResponse.success', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errors', full_name='qm.grpc.frontend.QmDataResponse.errors', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QMDATARESPONSE_IOVALUERESPONSE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4937,
  serialized_end=5218,
)


_IOVALUEREQUEST = _descriptor.Descriptor(
  name='IOValueRequest',
  full_name='qm.grpc.frontend.IOValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pulser_number', full_name='qm.grpc.frontend.IOValueRequest.pulser_number', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='io_number', full_name='qm.grpc.frontend.IOValueRequest.io_number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.IOValueRequest.jobId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantumMachineId', full_name='qm.grpc.frontend.IOValueRequest.quantumMachineId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='identifier_one_of', full_name='qm.grpc.frontend.IOValueRequest.identifier_one_of',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5221,
  serialized_end=5349,
)


_RESUMEREQUEST = _descriptor.Descriptor(
  name='ResumeRequest',
  full_name='qm.grpc.frontend.ResumeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.ResumeRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pulsersBitmap', full_name='qm.grpc.frontend.ResumeRequest.pulsersBitmap', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5351,
  serialized_end=5408,
)


_RESUMERESPONSE = _descriptor.Descriptor(
  name='ResumeResponse',
  full_name='qm.grpc.frontend.ResumeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5410,
  serialized_end=5426,
)


_PAUSEDSTATUSREQUEST = _descriptor.Descriptor(
  name='PausedStatusRequest',
  full_name='qm.grpc.frontend.PausedStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.PausedStatusRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5428,
  serialized_end=5464,
)


_PAUSEDSTATUSRESPONSE = _descriptor.Descriptor(
  name='PausedStatusResponse',
  full_name='qm.grpc.frontend.PausedStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pulsersBitmap', full_name='qm.grpc.frontend.PausedStatusResponse.pulsersBitmap', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ok', full_name='qm.grpc.frontend.PausedStatusResponse.ok', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isPaused', full_name='qm.grpc.frontend.PausedStatusResponse.isPaused', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5466,
  serialized_end=5545,
)


_PULLRESULTREQUEST = _descriptor.Descriptor(
  name='PullResultRequest',
  full_name='qm.grpc.frontend.PullResultRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.PullResultRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5547,
  serialized_end=5581,
)


_PULLANALYSEDRESULTSREQUEST = _descriptor.Descriptor(
  name='PullAnalysedResultsRequest',
  full_name='qm.grpc.frontend.PullAnalysedResultsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.PullAnalysedResultsRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='qm.grpc.frontend.PullAnalysedResultsRequest.metadata', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5583,
  serialized_end=5644,
)


_PULLRESULTRESPONSE = _descriptor.Descriptor(
  name='PullResultResponse',
  full_name='qm.grpc.frontend.PullResultResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='qm.grpc.frontend.PullResultResponse.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='qm.grpc.frontend.PullResultResponse.offset', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytesLeft', full_name='qm.grpc.frontend.PullResultResponse.bytesLeft', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controllerName', full_name='qm.grpc.frontend.PullResultResponse.controllerName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='applicationNumber', full_name='qm.grpc.frontend.PullResultResponse.applicationNumber', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='implementationName', full_name='qm.grpc.frontend.PullResultResponse.implementationName', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5647,
  serialized_end=5795,
)


_HEALTHCHECKRESPONSE = _descriptor.Descriptor(
  name='HealthCheckResponse',
  full_name='qm.grpc.frontend.HealthCheckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='qm.grpc.frontend.HealthCheckResponse.message', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ok', full_name='qm.grpc.frontend.HealthCheckResponse.ok', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errorMessages', full_name='qm.grpc.frontend.HealthCheckResponse.errorMessages', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warningMessages', full_name='qm.grpc.frontend.HealthCheckResponse.warningMessages', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5797,
  serialized_end=5895,
)


_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_NONE = _descriptor.Descriptor(
  name='None',
  full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.None',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7052,
  serialized_end=7058,
)

_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_LOOPBACK_CONNECTIONS = _descriptor.Descriptor(
  name='Connections',
  full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.Loopback.Connections',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fromController', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.Loopback.Connections.fromController', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fromPort', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.Loopback.Connections.fromPort', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toController', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.Loopback.Connections.toController', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toPort', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.Loopback.Connections.toPort', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7217,
  serialized_end=7310,
)

_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_LOOPBACK = _descriptor.Descriptor(
  name='Loopback',
  full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.Loopback',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connections', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.Loopback.connections', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latency', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.Loopback.latency', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='noisePower', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.Loopback.noisePower', index=2,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_LOOPBACK_CONNECTIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7061,
  serialized_end=7310,
)

_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QSIM_CONNECTIONS = _descriptor.Descriptor(
  name='Connections',
  full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QSim.Connections',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fromController', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QSim.Connections.fromController', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fromPort', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QSim.Connections.fromPort', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toQSim', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QSim.Connections.toQSim', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7688,
  serialized_end=7759,
)

_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QSIM = _descriptor.Descriptor(
  name='QSim',
  full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QSim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QSim.target', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QSim.jobId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='analogOutConnections', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QSim.analogOutConnections', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digitalOutConnections', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QSim.digitalOutConnections', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='analogInConnections', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QSim.analogInConnections', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QSIM_CONNECTIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7313,
  serialized_end=7759,
)

_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QUANTUMSIMULATORINTERFACE = _descriptor.Descriptor(
  name='QuantumSimulatorInterface',
  full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QuantumSimulatorInterface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='physical_config', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QuantumSimulatorInterface.physical_config', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7761,
  serialized_end=7813,
)

_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_RAWINTERFACE_CONNECTIONS = _descriptor.Descriptor(
  name='Connections',
  full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.RawInterface.Connections',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fromController', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.RawInterface.Connections.fromController', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fromPort', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.RawInterface.Connections.fromPort', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toSamples', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.RawInterface.Connections.toSamples', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7963,
  serialized_end=8037,
)

_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_RAWINTERFACE = _descriptor.Descriptor(
  name='RawInterface',
  full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.RawInterface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connections', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.RawInterface.connections', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='noisePower', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.RawInterface.noisePower', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_RAWINTERFACE_CONNECTIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7816,
  serialized_end=8037,
)

_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE = _descriptor.Descriptor(
  name='SimulationInterface',
  full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='none', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.none', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loopback', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.loopback', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qsim', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.qsim', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.raw', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantum_simulator', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.quantum_simulator', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_NONE, _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_LOOPBACK, _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QSIM, _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QUANTUMSIMULATORINTERFACE, _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_RAWINTERFACE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='interface_oneof', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.interface_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6550,
  serialized_end=8056,
)

_EXECUTIONREQUEST_SIMULATE = _descriptor.Descriptor(
  name='Simulate',
  full_name='qm.grpc.frontend.ExecutionRequest.Simulate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.duration', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulateAnalogOutputs', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.simulateAnalogOutputs', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulateDigitalOutputs', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.simulateDigitalOutputs', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includeAnalogSamples', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.includeAnalogSamples', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includeDigitalSamples', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.includeDigitalSamples', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includeAnalogWaveforms', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.includeAnalogWaveforms', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includeDigitalWaveforms', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.includeDigitalWaveforms', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulationInterface', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.simulationInterface', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extraProcessingTimeoutMs', full_name='qm.grpc.frontend.ExecutionRequest.Simulate.extraProcessingTimeoutMs', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6186,
  serialized_end=8056,
)

_EXECUTIONREQUEST = _descriptor.Descriptor(
  name='ExecutionRequest',
  full_name='qm.grpc.frontend.ExecutionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='highLevelProgram', full_name='qm.grpc.frontend.ExecutionRequest.highLevelProgram', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lowLevelProgram', full_name='qm.grpc.frontend.ExecutionRequest.lowLevelProgram', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streamDurationLimit', full_name='qm.grpc.frontend.ExecutionRequest.streamDurationLimit', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streamDataLimit', full_name='qm.grpc.frontend.ExecutionRequest.streamDataLimit', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forceExecution', full_name='qm.grpc.frontend.ExecutionRequest.forceExecution', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulate', full_name='qm.grpc.frontend.ExecutionRequest.simulate', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dryRun', full_name='qm.grpc.frontend.ExecutionRequest.dryRun', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantumMachineId', full_name='qm.grpc.frontend.ExecutionRequest.quantumMachineId', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXECUTIONREQUEST_SIMULATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='program_one_of', full_name='qm.grpc.frontend.ExecutionRequest.program_one_of',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5898,
  serialized_end=8074,
)


_EXECUTIONRESPONSE = _descriptor.Descriptor(
  name='ExecutionResponse',
  full_name='qm.grpc.frontend.ExecutionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='qm.grpc.frontend.ExecutionResponse.ok', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.ExecutionResponse.jobId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='qm.grpc.frontend.ExecutionResponse.messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='qm.grpc.frontend.ExecutionResponse.metadata', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulated', full_name='qm.grpc.frontend.ExecutionResponse.simulated', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='qm.grpc.frontend.ExecutionResponse.config', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8077,
  serialized_end=8301,
)


_SIMULATEDRESPONSEPART = _descriptor.Descriptor(
  name='SimulatedResponsePart',
  full_name='qm.grpc.frontend.SimulatedResponsePart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='analogOutputs', full_name='qm.grpc.frontend.SimulatedResponsePart.analogOutputs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digitalOutputs', full_name='qm.grpc.frontend.SimulatedResponsePart.digitalOutputs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errors', full_name='qm.grpc.frontend.SimulatedResponsePart.errors', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8304,
  serialized_end=8440,
)


_RESETDATAPROCESSINGREQUEST = _descriptor.Descriptor(
  name='ResetDataProcessingRequest',
  full_name='qm.grpc.frontend.ResetDataProcessingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8442,
  serialized_end=8470,
)


_RESETDATAPROCESSINGRESPONSE = _descriptor.Descriptor(
  name='ResetDataProcessingResponse',
  full_name='qm.grpc.frontend.ResetDataProcessingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8472,
  serialized_end=8501,
)


_HALTREQUEST = _descriptor.Descriptor(
  name='HaltRequest',
  full_name='qm.grpc.frontend.HaltRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.HaltRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8503,
  serialized_end=8531,
)


_HALTRESPONSE = _descriptor.Descriptor(
  name='HaltResponse',
  full_name='qm.grpc.frontend.HaltResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='qm.grpc.frontend.HaltResponse.ok', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8533,
  serialized_end=8559,
)


_PEEKREQUEST = _descriptor.Descriptor(
  name='PeekRequest',
  full_name='qm.grpc.frontend.PeekRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='qm.grpc.frontend.PeekRequest.address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controllerId', full_name='qm.grpc.frontend.PeekRequest.controllerId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8561,
  serialized_end=8613,
)


_PEEKRESPONSE = _descriptor.Descriptor(
  name='PeekResponse',
  full_name='qm.grpc.frontend.PeekResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.frontend.PeekResponse.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8615,
  serialized_end=8644,
)


_POKEREQUEST = _descriptor.Descriptor(
  name='PokeRequest',
  full_name='qm.grpc.frontend.PokeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='qm.grpc.frontend.PokeRequest.address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.frontend.PokeRequest.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controllerId', full_name='qm.grpc.frontend.PokeRequest.controllerId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8646,
  serialized_end=8713,
)


_POKERESPONSE = _descriptor.Descriptor(
  name='PokeResponse',
  full_name='qm.grpc.frontend.PokeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='qm.grpc.frontend.PokeResponse.ok', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8715,
  serialized_end=8741,
)


_GETSIMULATEDQUANTUMSTATEREQUEST = _descriptor.Descriptor(
  name='GetSimulatedQuantumStateRequest',
  full_name='qm.grpc.frontend.GetSimulatedQuantumStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.GetSimulatedQuantumStateRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8743,
  serialized_end=8791,
)


_GETSIMULATEDQUANTUMSTATERESPONSE = _descriptor.Descriptor(
  name='GetSimulatedQuantumStateResponse',
  full_name='qm.grpc.frontend.GetSimulatedQuantumStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.frontend.GetSimulatedQuantumStateResponse.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ok', full_name='qm.grpc.frontend.GetSimulatedQuantumStateResponse.ok', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='qm.grpc.frontend.GetSimulatedQuantumStateResponse.state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8793,
  serialized_end=8902,
)


_DENSITYMATRIX = _descriptor.Descriptor(
  name='DensityMatrix',
  full_name='qm.grpc.frontend.DensityMatrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeStamp', full_name='qm.grpc.frontend.DensityMatrix.timeStamp', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='qm.grpc.frontend.DensityMatrix.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8904,
  serialized_end=8985,
)


_COMPLEXNUMBER = _descriptor.Descriptor(
  name='ComplexNumber',
  full_name='qm.grpc.frontend.ComplexNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='re', full_name='qm.grpc.frontend.ComplexNumber.re', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='im', full_name='qm.grpc.frontend.ComplexNumber.im', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8987,
  serialized_end=9026,
)


_PERFORMHALDEBUGCOMMANDREQUEST = _descriptor.Descriptor(
  name='PerformHalDebugCommandRequest',
  full_name='qm.grpc.frontend.PerformHalDebugCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='controllerName', full_name='qm.grpc.frontend.PerformHalDebugCommandRequest.controllerName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='qm.grpc.frontend.PerformHalDebugCommandRequest.command', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9028,
  serialized_end=9100,
)


_PERFORMHALDEBUGCOMMANDRESPONSE = _descriptor.Descriptor(
  name='PerformHalDebugCommandResponse',
  full_name='qm.grpc.frontend.PerformHalDebugCommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='qm.grpc.frontend.PerformHalDebugCommandResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='qm.grpc.frontend.PerformHalDebugCommandResponse.response', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9102,
  serialized_end=9169,
)

_QUEUEPOSITION.fields_by_name['end'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_QUEUEPOSITION.fields_by_name['start'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_QUEUEPOSITION.oneofs_by_name['position'].fields.append(
  _QUEUEPOSITION.fields_by_name['end'])
_QUEUEPOSITION.fields_by_name['end'].containing_oneof = _QUEUEPOSITION.oneofs_by_name['position']
_QUEUEPOSITION.oneofs_by_name['position'].fields.append(
  _QUEUEPOSITION.fields_by_name['start'])
_QUEUEPOSITION.fields_by_name['start'].containing_oneof = _QUEUEPOSITION.oneofs_by_name['position']
_ADDTOQUEUEREQUEST.fields_by_name['highLevelProgram'].message_type = qm_dot_pb_dot_inc__qua__pb2._QUAPROGRAM
_ADDTOQUEUEREQUEST.fields_by_name['queuePosition'].message_type = _QUEUEPOSITION
_ADDTOQUEUERESPONSE.fields_by_name['messages'].message_type = qm_dot_pb_dot_compiler__pb2._COMPILERMESSAGE
_EXECUTIONOVERRIDES_WAVEFORMSENTRY.fields_by_name['value'].message_type = _WAVEFORMOVERRIDE
_EXECUTIONOVERRIDES_WAVEFORMSENTRY.containing_type = _EXECUTIONOVERRIDES
_EXECUTIONOVERRIDES.fields_by_name['waveforms'].message_type = _EXECUTIONOVERRIDES_WAVEFORMSENTRY
_ADDCOMPILEDTOQUEUEREQUEST.fields_by_name['queuePosition'].message_type = _QUEUEPOSITION
_ADDCOMPILEDTOQUEUEREQUEST.fields_by_name['executionOverrides'].message_type = _EXECUTIONOVERRIDES
_ADDCOMPILEDTOQUEUERESPONSE.fields_by_name['errors'].message_type = qm_dot_pb_dot_general__messages__pb2._ERRORMESSAGE
_COMPILEREQUEST.fields_by_name['highLevelProgram'].message_type = qm_dot_pb_dot_inc__qua__pb2._QUAPROGRAM
_COMPILERESPONSE.fields_by_name['messages'].message_type = qm_dot_pb_dot_compiler__pb2._COMPILERMESSAGE
_GETJOBEXECUTIONSTATUSRESPONSE.fields_by_name['status'].message_type = _JOBEXECUTIONSTATUS
_JOBEXECUTIONSTATUS_UNKNOWN.containing_type = _JOBEXECUTIONSTATUS
_JOBEXECUTIONSTATUS_PENDING.fields_by_name['timeAdded'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBEXECUTIONSTATUS_PENDING.containing_type = _JOBEXECUTIONSTATUS
_JOBEXECUTIONSTATUS_RUNNING.fields_by_name['timeAdded'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBEXECUTIONSTATUS_RUNNING.fields_by_name['timeStarted'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBEXECUTIONSTATUS_RUNNING.containing_type = _JOBEXECUTIONSTATUS
_JOBEXECUTIONSTATUS_COMPLETED.fields_by_name['timeAdded'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBEXECUTIONSTATUS_COMPLETED.fields_by_name['timeStarted'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBEXECUTIONSTATUS_COMPLETED.fields_by_name['timeCompleted'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBEXECUTIONSTATUS_COMPLETED.containing_type = _JOBEXECUTIONSTATUS
_JOBEXECUTIONSTATUS_CANCELED.fields_by_name['timeAdded'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBEXECUTIONSTATUS_CANCELED.fields_by_name['timeCanceled'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBEXECUTIONSTATUS_CANCELED.containing_type = _JOBEXECUTIONSTATUS
_JOBEXECUTIONSTATUS_LOADING.fields_by_name['timeAdded'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBEXECUTIONSTATUS_LOADING.containing_type = _JOBEXECUTIONSTATUS
_JOBEXECUTIONSTATUS.fields_by_name['unknown'].message_type = _JOBEXECUTIONSTATUS_UNKNOWN
_JOBEXECUTIONSTATUS.fields_by_name['pending'].message_type = _JOBEXECUTIONSTATUS_PENDING
_JOBEXECUTIONSTATUS.fields_by_name['running'].message_type = _JOBEXECUTIONSTATUS_RUNNING
_JOBEXECUTIONSTATUS.fields_by_name['completed'].message_type = _JOBEXECUTIONSTATUS_COMPLETED
_JOBEXECUTIONSTATUS.fields_by_name['canceled'].message_type = _JOBEXECUTIONSTATUS_CANCELED
_JOBEXECUTIONSTATUS.fields_by_name['loading'].message_type = _JOBEXECUTIONSTATUS_LOADING
_JOBEXECUTIONSTATUS.oneofs_by_name['status'].fields.append(
  _JOBEXECUTIONSTATUS.fields_by_name['unknown'])
_JOBEXECUTIONSTATUS.fields_by_name['unknown'].containing_oneof = _JOBEXECUTIONSTATUS.oneofs_by_name['status']
_JOBEXECUTIONSTATUS.oneofs_by_name['status'].fields.append(
  _JOBEXECUTIONSTATUS.fields_by_name['pending'])
_JOBEXECUTIONSTATUS.fields_by_name['pending'].containing_oneof = _JOBEXECUTIONSTATUS.oneofs_by_name['status']
_JOBEXECUTIONSTATUS.oneofs_by_name['status'].fields.append(
  _JOBEXECUTIONSTATUS.fields_by_name['running'])
_JOBEXECUTIONSTATUS.fields_by_name['running'].containing_oneof = _JOBEXECUTIONSTATUS.oneofs_by_name['status']
_JOBEXECUTIONSTATUS.oneofs_by_name['status'].fields.append(
  _JOBEXECUTIONSTATUS.fields_by_name['completed'])
_JOBEXECUTIONSTATUS.fields_by_name['completed'].containing_oneof = _JOBEXECUTIONSTATUS.oneofs_by_name['status']
_JOBEXECUTIONSTATUS.oneofs_by_name['status'].fields.append(
  _JOBEXECUTIONSTATUS.fields_by_name['canceled'])
_JOBEXECUTIONSTATUS.fields_by_name['canceled'].containing_oneof = _JOBEXECUTIONSTATUS.oneofs_by_name['status']
_JOBEXECUTIONSTATUS.oneofs_by_name['status'].fields.append(
  _JOBEXECUTIONSTATUS.fields_by_name['loading'])
_JOBEXECUTIONSTATUS.fields_by_name['loading'].containing_oneof = _JOBEXECUTIONSTATUS.oneofs_by_name['status']
_GETPENDINGJOBSRESPONSE_PENDINGJOBSENTRY.fields_by_name['value'].message_type = _JOBEXECUTIONSTATUS_PENDING
_GETPENDINGJOBSRESPONSE_PENDINGJOBSENTRY.containing_type = _GETPENDINGJOBSRESPONSE
_GETPENDINGJOBSRESPONSE.fields_by_name['pendingJobs'].message_type = _GETPENDINGJOBSRESPONSE_PENDINGJOBSENTRY
_JOBQUERYPARAMS.fields_by_name['jobId'].message_type = _QUERYVALUEMATCHER
_JOBQUERYPARAMS.fields_by_name['userId'].message_type = _QUERYVALUEMATCHER
_JOBQUERYPARAMS.fields_by_name['position'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_QUERYVALUEMATCHER.oneofs_by_name['valueType'].fields.append(
  _QUERYVALUEMATCHER.fields_by_name['any'])
_QUERYVALUEMATCHER.fields_by_name['any'].containing_oneof = _QUERYVALUEMATCHER.oneofs_by_name['valueType']
_QUERYVALUEMATCHER.oneofs_by_name['valueType'].fields.append(
  _QUERYVALUEMATCHER.fields_by_name['value'])
_QUERYVALUEMATCHER.fields_by_name['value'].containing_oneof = _QUERYVALUEMATCHER.oneofs_by_name['valueType']
_SIMULATIONREQUEST.fields_by_name['config'].message_type = qm_dot_pb_dot_inc__qua__config__pb2._QUACONFIG
_SIMULATIONREQUEST.fields_by_name['highLevelProgram'].message_type = qm_dot_pb_dot_inc__qua__pb2._QUAPROGRAM
_SIMULATIONREQUEST.fields_by_name['simulate'].message_type = _EXECUTIONREQUEST_SIMULATE
_SIMULATIONREQUEST.fields_by_name['controllerConnections'].message_type = _INTEROPXCONNECTION
_INTEROPXTARGET.fields_by_name['direct'].message_type = _INTEROPXADDRESS
_INTEROPXTARGET.oneofs_by_name['target'].fields.append(
  _INTEROPXTARGET.fields_by_name['direct'])
_INTEROPXTARGET.fields_by_name['direct'].containing_oneof = _INTEROPXTARGET.oneofs_by_name['target']
_INTEROPXCONNECTION_ADDRESSTOADDRESS.fields_by_name['source'].message_type = _INTEROPXADDRESS
_INTEROPXCONNECTION_ADDRESSTOADDRESS.fields_by_name['target'].message_type = _INTEROPXADDRESS
_INTEROPXCONNECTION_ADDRESSTOADDRESS.containing_type = _INTEROPXCONNECTION
_INTEROPXCONNECTION_CHANNELTOCHANNEL.fields_by_name['source'].message_type = _INTEROPXCHANNEL
_INTEROPXCONNECTION_CHANNELTOCHANNEL.fields_by_name['target'].message_type = _INTEROPXCHANNEL
_INTEROPXCONNECTION_CHANNELTOCHANNEL.containing_type = _INTEROPXCONNECTION
_INTEROPXCONNECTION.fields_by_name['source'].message_type = _INTEROPXADDRESS
_INTEROPXCONNECTION.fields_by_name['target'].message_type = _INTEROPXTARGET
_INTEROPXCONNECTION.fields_by_name['addressToAddress'].message_type = _INTEROPXCONNECTION_ADDRESSTOADDRESS
_INTEROPXCONNECTION.fields_by_name['channelToChannel'].message_type = _INTEROPXCONNECTION_CHANNELTOCHANNEL
_INTEROPXCONNECTION.oneofs_by_name['connectionType'].fields.append(
  _INTEROPXCONNECTION.fields_by_name['addressToAddress'])
_INTEROPXCONNECTION.fields_by_name['addressToAddress'].containing_oneof = _INTEROPXCONNECTION.oneofs_by_name['connectionType']
_INTEROPXCONNECTION.oneofs_by_name['connectionType'].fields.append(
  _INTEROPXCONNECTION.fields_by_name['channelToChannel'])
_INTEROPXCONNECTION.fields_by_name['channelToChannel'].containing_oneof = _INTEROPXCONNECTION.oneofs_by_name['connectionType']
_SIMULATIONRESPONSE.fields_by_name['configValidationErrors'].message_type = qm_dot_pb_dot_qm__manager__pb2._CONFIGVALIDATIONMESSAGE
_SIMULATIONRESPONSE.fields_by_name['physicalValidationErrors'].message_type = qm_dot_pb_dot_qm__manager__pb2._PHYSICALVALIDATIONMESSAGE
_SIMULATIONRESPONSE.fields_by_name['messages'].message_type = qm_dot_pb_dot_compiler__pb2._COMPILERMESSAGE
_SIMULATIONRESPONSE.fields_by_name['simulated'].message_type = _SIMULATEDRESPONSEPART
_ISJOBACQUIRINGDATARESPONSE.fields_by_name['acquiringStatus'].enum_type = _ISJOBACQUIRINGDATARESPONSE_ACQUIRINGSTATUS
_ISJOBACQUIRINGDATARESPONSE_ACQUIRINGSTATUS.containing_type = _ISJOBACQUIRINGDATARESPONSE
_QMDATAREQUEST.fields_by_name['io_value_Request'].message_type = _IOVALUEREQUEST
_QMDATARESPONSE_IOVALUERESPONSE.fields_by_name['request'].message_type = _IOVALUEREQUEST
_QMDATARESPONSE_IOVALUERESPONSE.fields_by_name['values'].message_type = qm_dot_pb_dot_compiler__pb2._QUAVALUES
_QMDATARESPONSE_IOVALUERESPONSE.containing_type = _QMDATARESPONSE
_QMDATARESPONSE.fields_by_name['io_value_response'].message_type = _QMDATARESPONSE_IOVALUERESPONSE
_QMDATARESPONSE.fields_by_name['errors'].message_type = qm_dot_pb_dot_general__messages__pb2._ERRORMESSAGE
_IOVALUEREQUEST.oneofs_by_name['identifier_one_of'].fields.append(
  _IOVALUEREQUEST.fields_by_name['jobId'])
_IOVALUEREQUEST.fields_by_name['jobId'].containing_oneof = _IOVALUEREQUEST.oneofs_by_name['identifier_one_of']
_IOVALUEREQUEST.oneofs_by_name['identifier_one_of'].fields.append(
  _IOVALUEREQUEST.fields_by_name['quantumMachineId'])
_IOVALUEREQUEST.fields_by_name['quantumMachineId'].containing_oneof = _IOVALUEREQUEST.oneofs_by_name['identifier_one_of']
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_NONE.containing_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_LOOPBACK_CONNECTIONS.containing_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_LOOPBACK
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_LOOPBACK.fields_by_name['connections'].message_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_LOOPBACK_CONNECTIONS
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_LOOPBACK.containing_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QSIM_CONNECTIONS.containing_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QSIM
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QSIM.fields_by_name['analogOutConnections'].message_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QSIM_CONNECTIONS
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QSIM.fields_by_name['digitalOutConnections'].message_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QSIM_CONNECTIONS
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QSIM.fields_by_name['analogInConnections'].message_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QSIM_CONNECTIONS
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QSIM.containing_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QUANTUMSIMULATORINTERFACE.containing_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_RAWINTERFACE_CONNECTIONS.containing_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_RAWINTERFACE
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_RAWINTERFACE.fields_by_name['connections'].message_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_RAWINTERFACE_CONNECTIONS
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_RAWINTERFACE.containing_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.fields_by_name['none'].message_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_NONE
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.fields_by_name['loopback'].message_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_LOOPBACK
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.fields_by_name['qsim'].message_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QSIM
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.fields_by_name['raw'].message_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_RAWINTERFACE
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.fields_by_name['quantum_simulator'].message_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QUANTUMSIMULATORINTERFACE
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.containing_type = _EXECUTIONREQUEST_SIMULATE
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.oneofs_by_name['interface_oneof'].fields.append(
  _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.fields_by_name['none'])
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.fields_by_name['none'].containing_oneof = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.oneofs_by_name['interface_oneof']
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.oneofs_by_name['interface_oneof'].fields.append(
  _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.fields_by_name['loopback'])
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.fields_by_name['loopback'].containing_oneof = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.oneofs_by_name['interface_oneof']
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.oneofs_by_name['interface_oneof'].fields.append(
  _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.fields_by_name['qsim'])
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.fields_by_name['qsim'].containing_oneof = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.oneofs_by_name['interface_oneof']
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.oneofs_by_name['interface_oneof'].fields.append(
  _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.fields_by_name['raw'])
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.fields_by_name['raw'].containing_oneof = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.oneofs_by_name['interface_oneof']
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.oneofs_by_name['interface_oneof'].fields.append(
  _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.fields_by_name['quantum_simulator'])
_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.fields_by_name['quantum_simulator'].containing_oneof = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE.oneofs_by_name['interface_oneof']
_EXECUTIONREQUEST_SIMULATE.fields_by_name['simulationInterface'].message_type = _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE
_EXECUTIONREQUEST_SIMULATE.containing_type = _EXECUTIONREQUEST
_EXECUTIONREQUEST.fields_by_name['highLevelProgram'].message_type = qm_dot_pb_dot_inc__qua__pb2._QUAPROGRAM
_EXECUTIONREQUEST.fields_by_name['simulate'].message_type = _EXECUTIONREQUEST_SIMULATE
_EXECUTIONREQUEST.oneofs_by_name['program_one_of'].fields.append(
  _EXECUTIONREQUEST.fields_by_name['highLevelProgram'])
_EXECUTIONREQUEST.fields_by_name['highLevelProgram'].containing_oneof = _EXECUTIONREQUEST.oneofs_by_name['program_one_of']
_EXECUTIONREQUEST.oneofs_by_name['program_one_of'].fields.append(
  _EXECUTIONREQUEST.fields_by_name['lowLevelProgram'])
_EXECUTIONREQUEST.fields_by_name['lowLevelProgram'].containing_oneof = _EXECUTIONREQUEST.oneofs_by_name['program_one_of']
_EXECUTIONRESPONSE.fields_by_name['messages'].message_type = qm_dot_pb_dot_compiler__pb2._COMPILERMESSAGE
_EXECUTIONRESPONSE.fields_by_name['simulated'].message_type = _SIMULATEDRESPONSEPART
_EXECUTIONRESPONSE.fields_by_name['config'].message_type = qm_dot_pb_dot_inc__qua__config__pb2._QUACONFIG
_SIMULATEDRESPONSEPART.fields_by_name['analogOutputs'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_SIMULATEDRESPONSEPART.fields_by_name['digitalOutputs'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_GETSIMULATEDQUANTUMSTATERESPONSE.fields_by_name['state'].message_type = _DENSITYMATRIX
_DENSITYMATRIX.fields_by_name['data'].message_type = _COMPLEXNUMBER
DESCRIPTOR.message_types_by_name['QueuePosition'] = _QUEUEPOSITION
DESCRIPTOR.message_types_by_name['AddToQueueRequest'] = _ADDTOQUEUEREQUEST
DESCRIPTOR.message_types_by_name['AddToQueueResponse'] = _ADDTOQUEUERESPONSE
DESCRIPTOR.message_types_by_name['WaveformOverride'] = _WAVEFORMOVERRIDE
DESCRIPTOR.message_types_by_name['ExecutionOverrides'] = _EXECUTIONOVERRIDES
DESCRIPTOR.message_types_by_name['AddCompiledToQueueRequest'] = _ADDCOMPILEDTOQUEUEREQUEST
DESCRIPTOR.message_types_by_name['AddCompiledToQueueResponse'] = _ADDCOMPILEDTOQUEUERESPONSE
DESCRIPTOR.message_types_by_name['CompileRequest'] = _COMPILEREQUEST
DESCRIPTOR.message_types_by_name['CompileResponse'] = _COMPILERESPONSE
DESCRIPTOR.message_types_by_name['GetJobExecutionStatusRequest'] = _GETJOBEXECUTIONSTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetJobExecutionStatusResponse'] = _GETJOBEXECUTIONSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['JobExecutionStatus'] = _JOBEXECUTIONSTATUS
DESCRIPTOR.message_types_by_name['GetPendingJobsResponse'] = _GETPENDINGJOBSRESPONSE
DESCRIPTOR.message_types_by_name['JobQueryParams'] = _JOBQUERYPARAMS
DESCRIPTOR.message_types_by_name['QueryValueMatcher'] = _QUERYVALUEMATCHER
DESCRIPTOR.message_types_by_name['RemovePendingJobsResponse'] = _REMOVEPENDINGJOBSRESPONSE
DESCRIPTOR.message_types_by_name['SimulationRequest'] = _SIMULATIONREQUEST
DESCRIPTOR.message_types_by_name['InterOpxAddress'] = _INTEROPXADDRESS
DESCRIPTOR.message_types_by_name['InterOpxTarget'] = _INTEROPXTARGET
DESCRIPTOR.message_types_by_name['InterOpxChannel'] = _INTEROPXCHANNEL
DESCRIPTOR.message_types_by_name['InterOpxConnection'] = _INTEROPXCONNECTION
DESCRIPTOR.message_types_by_name['SimulationResponse'] = _SIMULATIONRESPONSE
DESCRIPTOR.message_types_by_name['IsJobRunningRequest'] = _ISJOBRUNNINGREQUEST
DESCRIPTOR.message_types_by_name['IsJobRunningResponse'] = _ISJOBRUNNINGRESPONSE
DESCRIPTOR.message_types_by_name['IsJobAcquiringDataRequest'] = _ISJOBACQUIRINGDATAREQUEST
DESCRIPTOR.message_types_by_name['IsJobAcquiringDataResponse'] = _ISJOBACQUIRINGDATARESPONSE
DESCRIPTOR.message_types_by_name['QmDataRequest'] = _QMDATAREQUEST
DESCRIPTOR.message_types_by_name['QmDataResponse'] = _QMDATARESPONSE
DESCRIPTOR.message_types_by_name['IOValueRequest'] = _IOVALUEREQUEST
DESCRIPTOR.message_types_by_name['ResumeRequest'] = _RESUMEREQUEST
DESCRIPTOR.message_types_by_name['ResumeResponse'] = _RESUMERESPONSE
DESCRIPTOR.message_types_by_name['PausedStatusRequest'] = _PAUSEDSTATUSREQUEST
DESCRIPTOR.message_types_by_name['PausedStatusResponse'] = _PAUSEDSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['PullResultRequest'] = _PULLRESULTREQUEST
DESCRIPTOR.message_types_by_name['PullAnalysedResultsRequest'] = _PULLANALYSEDRESULTSREQUEST
DESCRIPTOR.message_types_by_name['PullResultResponse'] = _PULLRESULTRESPONSE
DESCRIPTOR.message_types_by_name['HealthCheckResponse'] = _HEALTHCHECKRESPONSE
DESCRIPTOR.message_types_by_name['ExecutionRequest'] = _EXECUTIONREQUEST
DESCRIPTOR.message_types_by_name['ExecutionResponse'] = _EXECUTIONRESPONSE
DESCRIPTOR.message_types_by_name['SimulatedResponsePart'] = _SIMULATEDRESPONSEPART
DESCRIPTOR.message_types_by_name['ResetDataProcessingRequest'] = _RESETDATAPROCESSINGREQUEST
DESCRIPTOR.message_types_by_name['ResetDataProcessingResponse'] = _RESETDATAPROCESSINGRESPONSE
DESCRIPTOR.message_types_by_name['HaltRequest'] = _HALTREQUEST
DESCRIPTOR.message_types_by_name['HaltResponse'] = _HALTRESPONSE
DESCRIPTOR.message_types_by_name['PeekRequest'] = _PEEKREQUEST
DESCRIPTOR.message_types_by_name['PeekResponse'] = _PEEKRESPONSE
DESCRIPTOR.message_types_by_name['PokeRequest'] = _POKEREQUEST
DESCRIPTOR.message_types_by_name['PokeResponse'] = _POKERESPONSE
DESCRIPTOR.message_types_by_name['GetSimulatedQuantumStateRequest'] = _GETSIMULATEDQUANTUMSTATEREQUEST
DESCRIPTOR.message_types_by_name['GetSimulatedQuantumStateResponse'] = _GETSIMULATEDQUANTUMSTATERESPONSE
DESCRIPTOR.message_types_by_name['DensityMatrix'] = _DENSITYMATRIX
DESCRIPTOR.message_types_by_name['ComplexNumber'] = _COMPLEXNUMBER
DESCRIPTOR.message_types_by_name['PerformHalDebugCommandRequest'] = _PERFORMHALDEBUGCOMMANDREQUEST
DESCRIPTOR.message_types_by_name['PerformHalDebugCommandResponse'] = _PERFORMHALDEBUGCOMMANDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueuePosition = _reflection.GeneratedProtocolMessageType('QueuePosition', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEPOSITION,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.QueuePosition)
  })
_sym_db.RegisterMessage(QueuePosition)

AddToQueueRequest = _reflection.GeneratedProtocolMessageType('AddToQueueRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDTOQUEUEREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.AddToQueueRequest)
  })
_sym_db.RegisterMessage(AddToQueueRequest)

AddToQueueResponse = _reflection.GeneratedProtocolMessageType('AddToQueueResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDTOQUEUERESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.AddToQueueResponse)
  })
_sym_db.RegisterMessage(AddToQueueResponse)

WaveformOverride = _reflection.GeneratedProtocolMessageType('WaveformOverride', (_message.Message,), {
  'DESCRIPTOR' : _WAVEFORMOVERRIDE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.WaveformOverride)
  })
_sym_db.RegisterMessage(WaveformOverride)

ExecutionOverrides = _reflection.GeneratedProtocolMessageType('ExecutionOverrides', (_message.Message,), {

  'WaveformsEntry' : _reflection.GeneratedProtocolMessageType('WaveformsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTIONOVERRIDES_WAVEFORMSENTRY,
    '__module__' : 'qm.pb.frontend_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ExecutionOverrides.WaveformsEntry)
    })
  ,
  'DESCRIPTOR' : _EXECUTIONOVERRIDES,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ExecutionOverrides)
  })
_sym_db.RegisterMessage(ExecutionOverrides)
_sym_db.RegisterMessage(ExecutionOverrides.WaveformsEntry)

AddCompiledToQueueRequest = _reflection.GeneratedProtocolMessageType('AddCompiledToQueueRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDCOMPILEDTOQUEUEREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.AddCompiledToQueueRequest)
  })
_sym_db.RegisterMessage(AddCompiledToQueueRequest)

AddCompiledToQueueResponse = _reflection.GeneratedProtocolMessageType('AddCompiledToQueueResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDCOMPILEDTOQUEUERESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.AddCompiledToQueueResponse)
  })
_sym_db.RegisterMessage(AddCompiledToQueueResponse)

CompileRequest = _reflection.GeneratedProtocolMessageType('CompileRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPILEREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.CompileRequest)
  })
_sym_db.RegisterMessage(CompileRequest)

CompileResponse = _reflection.GeneratedProtocolMessageType('CompileResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPILERESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.CompileResponse)
  })
_sym_db.RegisterMessage(CompileResponse)

GetJobExecutionStatusRequest = _reflection.GeneratedProtocolMessageType('GetJobExecutionStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBEXECUTIONSTATUSREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.GetJobExecutionStatusRequest)
  })
_sym_db.RegisterMessage(GetJobExecutionStatusRequest)

GetJobExecutionStatusResponse = _reflection.GeneratedProtocolMessageType('GetJobExecutionStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBEXECUTIONSTATUSRESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.GetJobExecutionStatusResponse)
  })
_sym_db.RegisterMessage(GetJobExecutionStatusResponse)

JobExecutionStatus = _reflection.GeneratedProtocolMessageType('JobExecutionStatus', (_message.Message,), {

  'Unknown' : _reflection.GeneratedProtocolMessageType('Unknown', (_message.Message,), {
    'DESCRIPTOR' : _JOBEXECUTIONSTATUS_UNKNOWN,
    '__module__' : 'qm.pb.frontend_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.frontend.JobExecutionStatus.Unknown)
    })
  ,

  'Pending' : _reflection.GeneratedProtocolMessageType('Pending', (_message.Message,), {
    'DESCRIPTOR' : _JOBEXECUTIONSTATUS_PENDING,
    '__module__' : 'qm.pb.frontend_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.frontend.JobExecutionStatus.Pending)
    })
  ,

  'Running' : _reflection.GeneratedProtocolMessageType('Running', (_message.Message,), {
    'DESCRIPTOR' : _JOBEXECUTIONSTATUS_RUNNING,
    '__module__' : 'qm.pb.frontend_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.frontend.JobExecutionStatus.Running)
    })
  ,

  'Completed' : _reflection.GeneratedProtocolMessageType('Completed', (_message.Message,), {
    'DESCRIPTOR' : _JOBEXECUTIONSTATUS_COMPLETED,
    '__module__' : 'qm.pb.frontend_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.frontend.JobExecutionStatus.Completed)
    })
  ,

  'Canceled' : _reflection.GeneratedProtocolMessageType('Canceled', (_message.Message,), {
    'DESCRIPTOR' : _JOBEXECUTIONSTATUS_CANCELED,
    '__module__' : 'qm.pb.frontend_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.frontend.JobExecutionStatus.Canceled)
    })
  ,

  'Loading' : _reflection.GeneratedProtocolMessageType('Loading', (_message.Message,), {
    'DESCRIPTOR' : _JOBEXECUTIONSTATUS_LOADING,
    '__module__' : 'qm.pb.frontend_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.frontend.JobExecutionStatus.Loading)
    })
  ,
  'DESCRIPTOR' : _JOBEXECUTIONSTATUS,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.JobExecutionStatus)
  })
_sym_db.RegisterMessage(JobExecutionStatus)
_sym_db.RegisterMessage(JobExecutionStatus.Unknown)
_sym_db.RegisterMessage(JobExecutionStatus.Pending)
_sym_db.RegisterMessage(JobExecutionStatus.Running)
_sym_db.RegisterMessage(JobExecutionStatus.Completed)
_sym_db.RegisterMessage(JobExecutionStatus.Canceled)
_sym_db.RegisterMessage(JobExecutionStatus.Loading)

GetPendingJobsResponse = _reflection.GeneratedProtocolMessageType('GetPendingJobsResponse', (_message.Message,), {

  'PendingJobsEntry' : _reflection.GeneratedProtocolMessageType('PendingJobsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETPENDINGJOBSRESPONSE_PENDINGJOBSENTRY,
    '__module__' : 'qm.pb.frontend_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.frontend.GetPendingJobsResponse.PendingJobsEntry)
    })
  ,
  'DESCRIPTOR' : _GETPENDINGJOBSRESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.GetPendingJobsResponse)
  })
_sym_db.RegisterMessage(GetPendingJobsResponse)
_sym_db.RegisterMessage(GetPendingJobsResponse.PendingJobsEntry)

JobQueryParams = _reflection.GeneratedProtocolMessageType('JobQueryParams', (_message.Message,), {
  'DESCRIPTOR' : _JOBQUERYPARAMS,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.JobQueryParams)
  })
_sym_db.RegisterMessage(JobQueryParams)

QueryValueMatcher = _reflection.GeneratedProtocolMessageType('QueryValueMatcher', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALUEMATCHER,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.QueryValueMatcher)
  })
_sym_db.RegisterMessage(QueryValueMatcher)

RemovePendingJobsResponse = _reflection.GeneratedProtocolMessageType('RemovePendingJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPENDINGJOBSRESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.RemovePendingJobsResponse)
  })
_sym_db.RegisterMessage(RemovePendingJobsResponse)

SimulationRequest = _reflection.GeneratedProtocolMessageType('SimulationRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATIONREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.SimulationRequest)
  })
_sym_db.RegisterMessage(SimulationRequest)

InterOpxAddress = _reflection.GeneratedProtocolMessageType('InterOpxAddress', (_message.Message,), {
  'DESCRIPTOR' : _INTEROPXADDRESS,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.InterOpxAddress)
  })
_sym_db.RegisterMessage(InterOpxAddress)

InterOpxTarget = _reflection.GeneratedProtocolMessageType('InterOpxTarget', (_message.Message,), {
  'DESCRIPTOR' : _INTEROPXTARGET,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.InterOpxTarget)
  })
_sym_db.RegisterMessage(InterOpxTarget)

InterOpxChannel = _reflection.GeneratedProtocolMessageType('InterOpxChannel', (_message.Message,), {
  'DESCRIPTOR' : _INTEROPXCHANNEL,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.InterOpxChannel)
  })
_sym_db.RegisterMessage(InterOpxChannel)

InterOpxConnection = _reflection.GeneratedProtocolMessageType('InterOpxConnection', (_message.Message,), {

  'AddressToAddress' : _reflection.GeneratedProtocolMessageType('AddressToAddress', (_message.Message,), {
    'DESCRIPTOR' : _INTEROPXCONNECTION_ADDRESSTOADDRESS,
    '__module__' : 'qm.pb.frontend_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.frontend.InterOpxConnection.AddressToAddress)
    })
  ,

  'ChannelToChannel' : _reflection.GeneratedProtocolMessageType('ChannelToChannel', (_message.Message,), {
    'DESCRIPTOR' : _INTEROPXCONNECTION_CHANNELTOCHANNEL,
    '__module__' : 'qm.pb.frontend_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.frontend.InterOpxConnection.ChannelToChannel)
    })
  ,
  'DESCRIPTOR' : _INTEROPXCONNECTION,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.InterOpxConnection)
  })
_sym_db.RegisterMessage(InterOpxConnection)
_sym_db.RegisterMessage(InterOpxConnection.AddressToAddress)
_sym_db.RegisterMessage(InterOpxConnection.ChannelToChannel)

SimulationResponse = _reflection.GeneratedProtocolMessageType('SimulationResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATIONRESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.SimulationResponse)
  })
_sym_db.RegisterMessage(SimulationResponse)

IsJobRunningRequest = _reflection.GeneratedProtocolMessageType('IsJobRunningRequest', (_message.Message,), {
  'DESCRIPTOR' : _ISJOBRUNNINGREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.IsJobRunningRequest)
  })
_sym_db.RegisterMessage(IsJobRunningRequest)

IsJobRunningResponse = _reflection.GeneratedProtocolMessageType('IsJobRunningResponse', (_message.Message,), {
  'DESCRIPTOR' : _ISJOBRUNNINGRESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.IsJobRunningResponse)
  })
_sym_db.RegisterMessage(IsJobRunningResponse)

IsJobAcquiringDataRequest = _reflection.GeneratedProtocolMessageType('IsJobAcquiringDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _ISJOBACQUIRINGDATAREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.IsJobAcquiringDataRequest)
  })
_sym_db.RegisterMessage(IsJobAcquiringDataRequest)

IsJobAcquiringDataResponse = _reflection.GeneratedProtocolMessageType('IsJobAcquiringDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _ISJOBACQUIRINGDATARESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.IsJobAcquiringDataResponse)
  })
_sym_db.RegisterMessage(IsJobAcquiringDataResponse)

QmDataRequest = _reflection.GeneratedProtocolMessageType('QmDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _QMDATAREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.QmDataRequest)
  })
_sym_db.RegisterMessage(QmDataRequest)

QmDataResponse = _reflection.GeneratedProtocolMessageType('QmDataResponse', (_message.Message,), {

  'IOValueResponse' : _reflection.GeneratedProtocolMessageType('IOValueResponse', (_message.Message,), {
    'DESCRIPTOR' : _QMDATARESPONSE_IOVALUERESPONSE,
    '__module__' : 'qm.pb.frontend_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.frontend.QmDataResponse.IOValueResponse)
    })
  ,
  'DESCRIPTOR' : _QMDATARESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.QmDataResponse)
  })
_sym_db.RegisterMessage(QmDataResponse)
_sym_db.RegisterMessage(QmDataResponse.IOValueResponse)

IOValueRequest = _reflection.GeneratedProtocolMessageType('IOValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _IOVALUEREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.IOValueRequest)
  })
_sym_db.RegisterMessage(IOValueRequest)

ResumeRequest = _reflection.GeneratedProtocolMessageType('ResumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ResumeRequest)
  })
_sym_db.RegisterMessage(ResumeRequest)

ResumeResponse = _reflection.GeneratedProtocolMessageType('ResumeResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMERESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ResumeResponse)
  })
_sym_db.RegisterMessage(ResumeResponse)

PausedStatusRequest = _reflection.GeneratedProtocolMessageType('PausedStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEDSTATUSREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.PausedStatusRequest)
  })
_sym_db.RegisterMessage(PausedStatusRequest)

PausedStatusResponse = _reflection.GeneratedProtocolMessageType('PausedStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEDSTATUSRESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.PausedStatusResponse)
  })
_sym_db.RegisterMessage(PausedStatusResponse)

PullResultRequest = _reflection.GeneratedProtocolMessageType('PullResultRequest', (_message.Message,), {
  'DESCRIPTOR' : _PULLRESULTREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.PullResultRequest)
  })
_sym_db.RegisterMessage(PullResultRequest)

PullAnalysedResultsRequest = _reflection.GeneratedProtocolMessageType('PullAnalysedResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _PULLANALYSEDRESULTSREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.PullAnalysedResultsRequest)
  })
_sym_db.RegisterMessage(PullAnalysedResultsRequest)

PullResultResponse = _reflection.GeneratedProtocolMessageType('PullResultResponse', (_message.Message,), {
  'DESCRIPTOR' : _PULLRESULTRESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.PullResultResponse)
  })
_sym_db.RegisterMessage(PullResultResponse)

HealthCheckResponse = _reflection.GeneratedProtocolMessageType('HealthCheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKRESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.HealthCheckResponse)
  })
_sym_db.RegisterMessage(HealthCheckResponse)

ExecutionRequest = _reflection.GeneratedProtocolMessageType('ExecutionRequest', (_message.Message,), {

  'Simulate' : _reflection.GeneratedProtocolMessageType('Simulate', (_message.Message,), {

    'SimulationInterface' : _reflection.GeneratedProtocolMessageType('SimulationInterface', (_message.Message,), {

      'None' : _reflection.GeneratedProtocolMessageType('None', (_message.Message,), {
        'DESCRIPTOR' : _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_NONE,
        '__module__' : 'qm.pb.frontend_pb2'
        # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.None)
        })
      ,

      'Loopback' : _reflection.GeneratedProtocolMessageType('Loopback', (_message.Message,), {

        'Connections' : _reflection.GeneratedProtocolMessageType('Connections', (_message.Message,), {
          'DESCRIPTOR' : _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_LOOPBACK_CONNECTIONS,
          '__module__' : 'qm.pb.frontend_pb2'
          # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.Loopback.Connections)
          })
        ,
        'DESCRIPTOR' : _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_LOOPBACK,
        '__module__' : 'qm.pb.frontend_pb2'
        # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.Loopback)
        })
      ,

      'QSim' : _reflection.GeneratedProtocolMessageType('QSim', (_message.Message,), {

        'Connections' : _reflection.GeneratedProtocolMessageType('Connections', (_message.Message,), {
          'DESCRIPTOR' : _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QSIM_CONNECTIONS,
          '__module__' : 'qm.pb.frontend_pb2'
          # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QSim.Connections)
          })
        ,
        'DESCRIPTOR' : _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QSIM,
        '__module__' : 'qm.pb.frontend_pb2'
        # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QSim)
        })
      ,

      'QuantumSimulatorInterface' : _reflection.GeneratedProtocolMessageType('QuantumSimulatorInterface', (_message.Message,), {
        'DESCRIPTOR' : _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_QUANTUMSIMULATORINTERFACE,
        '__module__' : 'qm.pb.frontend_pb2'
        # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.QuantumSimulatorInterface)
        })
      ,

      'RawInterface' : _reflection.GeneratedProtocolMessageType('RawInterface', (_message.Message,), {

        'Connections' : _reflection.GeneratedProtocolMessageType('Connections', (_message.Message,), {
          'DESCRIPTOR' : _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_RAWINTERFACE_CONNECTIONS,
          '__module__' : 'qm.pb.frontend_pb2'
          # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.RawInterface.Connections)
          })
        ,
        'DESCRIPTOR' : _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_RAWINTERFACE,
        '__module__' : 'qm.pb.frontend_pb2'
        # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.RawInterface)
        })
      ,
      'DESCRIPTOR' : _EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE,
      '__module__' : 'qm.pb.frontend_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface)
      })
    ,
    'DESCRIPTOR' : _EXECUTIONREQUEST_SIMULATE,
    '__module__' : 'qm.pb.frontend_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ExecutionRequest.Simulate)
    })
  ,
  'DESCRIPTOR' : _EXECUTIONREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ExecutionRequest)
  })
_sym_db.RegisterMessage(ExecutionRequest)
_sym_db.RegisterMessage(ExecutionRequest.Simulate)
_sym_db.RegisterMessage(ExecutionRequest.Simulate.SimulationInterface)
_sym_db.RegisterMessage(getattr(ExecutionRequest.Simulate.SimulationInterface, 'None'))
_sym_db.RegisterMessage(ExecutionRequest.Simulate.SimulationInterface.Loopback)
_sym_db.RegisterMessage(ExecutionRequest.Simulate.SimulationInterface.Loopback.Connections)
_sym_db.RegisterMessage(ExecutionRequest.Simulate.SimulationInterface.QSim)
_sym_db.RegisterMessage(ExecutionRequest.Simulate.SimulationInterface.QSim.Connections)
_sym_db.RegisterMessage(ExecutionRequest.Simulate.SimulationInterface.QuantumSimulatorInterface)
_sym_db.RegisterMessage(ExecutionRequest.Simulate.SimulationInterface.RawInterface)
_sym_db.RegisterMessage(ExecutionRequest.Simulate.SimulationInterface.RawInterface.Connections)

ExecutionResponse = _reflection.GeneratedProtocolMessageType('ExecutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTIONRESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ExecutionResponse)
  })
_sym_db.RegisterMessage(ExecutionResponse)

SimulatedResponsePart = _reflection.GeneratedProtocolMessageType('SimulatedResponsePart', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATEDRESPONSEPART,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.SimulatedResponsePart)
  })
_sym_db.RegisterMessage(SimulatedResponsePart)

ResetDataProcessingRequest = _reflection.GeneratedProtocolMessageType('ResetDataProcessingRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESETDATAPROCESSINGREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ResetDataProcessingRequest)
  })
_sym_db.RegisterMessage(ResetDataProcessingRequest)

ResetDataProcessingResponse = _reflection.GeneratedProtocolMessageType('ResetDataProcessingResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETDATAPROCESSINGRESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ResetDataProcessingResponse)
  })
_sym_db.RegisterMessage(ResetDataProcessingResponse)

HaltRequest = _reflection.GeneratedProtocolMessageType('HaltRequest', (_message.Message,), {
  'DESCRIPTOR' : _HALTREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.HaltRequest)
  })
_sym_db.RegisterMessage(HaltRequest)

HaltResponse = _reflection.GeneratedProtocolMessageType('HaltResponse', (_message.Message,), {
  'DESCRIPTOR' : _HALTRESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.HaltResponse)
  })
_sym_db.RegisterMessage(HaltResponse)

PeekRequest = _reflection.GeneratedProtocolMessageType('PeekRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEEKREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.PeekRequest)
  })
_sym_db.RegisterMessage(PeekRequest)

PeekResponse = _reflection.GeneratedProtocolMessageType('PeekResponse', (_message.Message,), {
  'DESCRIPTOR' : _PEEKRESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.PeekResponse)
  })
_sym_db.RegisterMessage(PeekResponse)

PokeRequest = _reflection.GeneratedProtocolMessageType('PokeRequest', (_message.Message,), {
  'DESCRIPTOR' : _POKEREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.PokeRequest)
  })
_sym_db.RegisterMessage(PokeRequest)

PokeResponse = _reflection.GeneratedProtocolMessageType('PokeResponse', (_message.Message,), {
  'DESCRIPTOR' : _POKERESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.PokeResponse)
  })
_sym_db.RegisterMessage(PokeResponse)

GetSimulatedQuantumStateRequest = _reflection.GeneratedProtocolMessageType('GetSimulatedQuantumStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSIMULATEDQUANTUMSTATEREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.GetSimulatedQuantumStateRequest)
  })
_sym_db.RegisterMessage(GetSimulatedQuantumStateRequest)

GetSimulatedQuantumStateResponse = _reflection.GeneratedProtocolMessageType('GetSimulatedQuantumStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSIMULATEDQUANTUMSTATERESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.GetSimulatedQuantumStateResponse)
  })
_sym_db.RegisterMessage(GetSimulatedQuantumStateResponse)

DensityMatrix = _reflection.GeneratedProtocolMessageType('DensityMatrix', (_message.Message,), {
  'DESCRIPTOR' : _DENSITYMATRIX,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.DensityMatrix)
  })
_sym_db.RegisterMessage(DensityMatrix)

ComplexNumber = _reflection.GeneratedProtocolMessageType('ComplexNumber', (_message.Message,), {
  'DESCRIPTOR' : _COMPLEXNUMBER,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.ComplexNumber)
  })
_sym_db.RegisterMessage(ComplexNumber)

PerformHalDebugCommandRequest = _reflection.GeneratedProtocolMessageType('PerformHalDebugCommandRequest', (_message.Message,), {
  'DESCRIPTOR' : _PERFORMHALDEBUGCOMMANDREQUEST,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.PerformHalDebugCommandRequest)
  })
_sym_db.RegisterMessage(PerformHalDebugCommandRequest)

PerformHalDebugCommandResponse = _reflection.GeneratedProtocolMessageType('PerformHalDebugCommandResponse', (_message.Message,), {
  'DESCRIPTOR' : _PERFORMHALDEBUGCOMMANDRESPONSE,
  '__module__' : 'qm.pb.frontend_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.frontend.PerformHalDebugCommandResponse)
  })
_sym_db.RegisterMessage(PerformHalDebugCommandResponse)


DESCRIPTOR._options = None
_EXECUTIONOVERRIDES_WAVEFORMSENTRY._options = None
_GETPENDINGJOBSRESPONSE_PENDINGJOBSENTRY._options = None
_INTEROPXCONNECTION.fields_by_name['source']._options = None
_INTEROPXCONNECTION.fields_by_name['target']._options = None
_IOVALUEREQUEST.fields_by_name['pulser_number']._options = None
_RESUMEREQUEST.fields_by_name['pulsersBitmap']._options = None
_PAUSEDSTATUSRESPONSE.fields_by_name['pulsersBitmap']._options = None
_EXECUTIONREQUEST_SIMULATE.fields_by_name['simulateAnalogOutputs']._options = None
_EXECUTIONREQUEST_SIMULATE.fields_by_name['simulateDigitalOutputs']._options = None
_EXECUTIONREQUEST_SIMULATE.fields_by_name['includeAnalogSamples']._options = None
_EXECUTIONREQUEST_SIMULATE.fields_by_name['includeDigitalSamples']._options = None
_EXECUTIONREQUEST.fields_by_name['lowLevelProgram']._options = None

_FRONTEND = _descriptor.ServiceDescriptor(
  name='Frontend',
  full_name='qm.grpc.frontend.Frontend',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=9172,
  serialized_end=12248,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetVersion',
    full_name='qm.grpc.frontend.Frontend.GetVersion',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='HealthCheck',
    full_name='qm.grpc.frontend.Frontend.HealthCheck',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_HEALTHCHECKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Execute',
    full_name='qm.grpc.frontend.Frontend.Execute',
    index=2,
    containing_service=None,
    input_type=_EXECUTIONREQUEST,
    output_type=_EXECUTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddToQueue',
    full_name='qm.grpc.frontend.Frontend.AddToQueue',
    index=3,
    containing_service=None,
    input_type=_ADDTOQUEUEREQUEST,
    output_type=_ADDTOQUEUERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Compile',
    full_name='qm.grpc.frontend.Frontend.Compile',
    index=4,
    containing_service=None,
    input_type=_COMPILEREQUEST,
    output_type=_COMPILERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddCompiledToQueue',
    full_name='qm.grpc.frontend.Frontend.AddCompiledToQueue',
    index=5,
    containing_service=None,
    input_type=_ADDCOMPILEDTOQUEUEREQUEST,
    output_type=_ADDCOMPILEDTOQUEUERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemovePendingJobs',
    full_name='qm.grpc.frontend.Frontend.RemovePendingJobs',
    index=6,
    containing_service=None,
    input_type=_JOBQUERYPARAMS,
    output_type=_REMOVEPENDINGJOBSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPendingJobs',
    full_name='qm.grpc.frontend.Frontend.GetPendingJobs',
    index=7,
    containing_service=None,
    input_type=_JOBQUERYPARAMS,
    output_type=_GETPENDINGJOBSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetJobExecutionStatus',
    full_name='qm.grpc.frontend.Frontend.GetJobExecutionStatus',
    index=8,
    containing_service=None,
    input_type=_GETJOBEXECUTIONSTATUSREQUEST,
    output_type=_GETJOBEXECUTIONSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PausedStatus',
    full_name='qm.grpc.frontend.Frontend.PausedStatus',
    index=9,
    containing_service=None,
    input_type=_PAUSEDSTATUSREQUEST,
    output_type=_PAUSEDSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Resume',
    full_name='qm.grpc.frontend.Frontend.Resume',
    index=10,
    containing_service=None,
    input_type=_RESUMEREQUEST,
    output_type=_RESUMERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Halt',
    full_name='qm.grpc.frontend.Frontend.Halt',
    index=11,
    containing_service=None,
    input_type=_HALTREQUEST,
    output_type=_HALTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetDataProcessing',
    full_name='qm.grpc.frontend.Frontend.ResetDataProcessing',
    index=12,
    containing_service=None,
    input_type=_RESETDATAPROCESSINGREQUEST,
    output_type=_RESETDATAPROCESSINGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ValidateConfig',
    full_name='qm.grpc.frontend.Frontend.ValidateConfig',
    index=13,
    containing_service=None,
    input_type=qm_dot_pb_dot_inc__qua__config__pb2._QUACONFIG,
    output_type=qm_dot_pb_dot_compiler__pb2._VALIDATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Init',
    full_name='qm.grpc.frontend.Frontend.Init',
    index=14,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PerformQmRequest',
    full_name='qm.grpc.frontend.Frontend.PerformQmRequest',
    index=15,
    containing_service=None,
    input_type=qm_dot_pb_dot_inc__qm__api__pb2._HIGHQMAPIREQUEST,
    output_type=qm_dot_pb_dot_inc__qm__api__pb2._HIGHQMAPIRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestData',
    full_name='qm.grpc.frontend.Frontend.RequestData',
    index=16,
    containing_service=None,
    input_type=_QMDATAREQUEST,
    output_type=_QMDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PullSimulatorSamples',
    full_name='qm.grpc.frontend.Frontend.PullSimulatorSamples',
    index=17,
    containing_service=None,
    input_type=qm_dot_pb_dot_job__results__pb2._PULLSIMULATORSAMPLESREQUEST,
    output_type=qm_dot_pb_dot_job__results__pb2._SIMULATORSAMPLESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OpenQuantumMachine',
    full_name='qm.grpc.frontend.Frontend.OpenQuantumMachine',
    index=18,
    containing_service=None,
    input_type=qm_dot_pb_dot_qm__manager__pb2._OPENQUANTUMMACHINEREQUEST,
    output_type=qm_dot_pb_dot_qm__manager__pb2._OPENQUANTUMMACHINERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CloseQuantumMachine',
    full_name='qm.grpc.frontend.Frontend.CloseQuantumMachine',
    index=19,
    containing_service=None,
    input_type=qm_dot_pb_dot_qm__manager__pb2._CLOSEQUANTUMMACHINEREQUEST,
    output_type=qm_dot_pb_dot_qm__manager__pb2._CLOSEQUANTUMMACHINERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetQuantumMachine',
    full_name='qm.grpc.frontend.Frontend.GetQuantumMachine',
    index=20,
    containing_service=None,
    input_type=qm_dot_pb_dot_qm__manager__pb2._GETQUANTUMMACHINEREQUEST,
    output_type=qm_dot_pb_dot_qm__manager__pb2._GETQUANTUMMACHINERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRunningJob',
    full_name='qm.grpc.frontend.Frontend.GetRunningJob',
    index=21,
    containing_service=None,
    input_type=qm_dot_pb_dot_qm__manager__pb2._GETRUNNINGJOBREQUEST,
    output_type=qm_dot_pb_dot_qm__manager__pb2._GETRUNNINGJOBRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOpenQuantumMachines',
    full_name='qm.grpc.frontend.Frontend.ListOpenQuantumMachines',
    index=22,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=qm_dot_pb_dot_qm__manager__pb2._LISTOPENQUANTUMMACHINESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CloseAllQuantumMachines',
    full_name='qm.grpc.frontend.Frontend.CloseAllQuantumMachines',
    index=23,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=qm_dot_pb_dot_qm__manager__pb2._CLOSEALLQUANTUMMACHINESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetControllers',
    full_name='qm.grpc.frontend.Frontend.GetControllers',
    index=24,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=qm_dot_pb_dot_qm__manager__pb2._GETCONTROLLERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IsJobRunning',
    full_name='qm.grpc.frontend.Frontend.IsJobRunning',
    index=25,
    containing_service=None,
    input_type=_ISJOBRUNNINGREQUEST,
    output_type=_ISJOBRUNNINGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IsJobAcquiringData',
    full_name='qm.grpc.frontend.Frontend.IsJobAcquiringData',
    index=26,
    containing_service=None,
    input_type=_ISJOBACQUIRINGDATAREQUEST,
    output_type=_ISJOBACQUIRINGDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Simulate',
    full_name='qm.grpc.frontend.Frontend.Simulate',
    index=27,
    containing_service=None,
    input_type=_SIMULATIONREQUEST,
    output_type=_SIMULATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClearAllJobResults',
    full_name='qm.grpc.frontend.Frontend.ClearAllJobResults',
    index=28,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PerformHalDebugCommand',
    full_name='qm.grpc.frontend.Frontend.PerformHalDebugCommand',
    index=29,
    containing_service=None,
    input_type=_PERFORMHALDEBUGCOMMANDREQUEST,
    output_type=_PERFORMHALDEBUGCOMMANDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSimulatedQuantumState',
    full_name='qm.grpc.frontend.Frontend.GetSimulatedQuantumState',
    index=30,
    containing_service=None,
    input_type=_GETSIMULATEDQUANTUMSTATEREQUEST,
    output_type=_GETSIMULATEDQUANTUMSTATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FRONTEND)

DESCRIPTOR.services_by_name['Frontend'] = _FRONTEND

# @@protoc_insertion_point(module_scope)
